from __future__ import annotations

from typing import Any, Optional

from ...fluid import dygraph_utils as dygraph_utils
from ...fluid import layers as layers
from ...fluid.data_feeder import check_dtype as check_dtype
from ...fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ...fluid.framework import in_dygraph_mode as in_dygraph_mode
from ...fluid.layers import unfold as unfold
from ...tensor import clip as clip
from ...tensor import concat as concat
from ...tensor import sqrt as sqrt
from ...tensor import sum as sum
from ...tensor.creation import zeros as zeros
from ...tensor.manipulation import squeeze as squeeze
from ...tensor.manipulation import unsqueeze as unsqueeze

def interpolate(
    x: Any,
    size: Optional[Any] = ...,
    scale_factor: Optional[Any] = ...,
    mode: str = ...,
    align_corners: bool = ...,
    align_mode: int = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def upsample(
    x: Any,
    size: Optional[Any] = ...,
    scale_factor: Optional[Any] = ...,
    mode: str = ...,
    align_corners: bool = ...,
    align_mode: int = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def bilinear(x1: Any, x2: Any, weight: Any, bias: Optional[Any] = ..., name: Optional[Any] = ...): ...
def dropout(
    x: Any, p: float = ..., axis: Optional[Any] = ..., training: bool = ..., mode: str = ..., name: Optional[Any] = ...
): ...
def dropout2d(x: Any, p: float = ..., training: bool = ..., data_format: str = ..., name: Optional[Any] = ...): ...
def dropout3d(x: Any, p: float = ..., training: bool = ..., data_format: str = ..., name: Optional[Any] = ...): ...
def alpha_dropout(x: Any, p: float = ..., training: bool = ..., name: Optional[Any] = ...): ...
def pad(x: Any, pad: Any, mode: str = ..., value: int = ..., data_format: str = ..., name: Optional[Any] = ...): ...
def zeropad2d(x: Any, padding: Any, data_format: str = ..., name: Optional[Any] = ...): ...
def cosine_similarity(x1: Any, x2: Any, axis: int = ..., eps: float = ...): ...
def linear(x: Any, weight: Any, bias: Optional[Any] = ..., name: Optional[Any] = ...): ...
def label_smooth(label: Any, prior_dist: Optional[Any] = ..., epsilon: float = ..., name: Optional[Any] = ...): ...
def class_center_sample(label: Any, num_classes: Any, num_samples: Any, group: Optional[Any] = ...): ...
def fold(
    x: Any,
    output_sizes: Any,
    kernel_sizes: Any,
    strides: int = ...,
    paddings: int = ...,
    dilations: int = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

VOC_URL: str
VOC_MD5: str
SET_FILE: str
DATA_FILE: str
LABEL_FILE: str
CACHE_DIR: str
MODE_FLAG_MAP: Any

class VOC2012(Dataset):
    backend: Any = ...
    flag: Any = ...
    data_file: Any = ...
    transform: Any = ...
    dtype: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        mode: str = ...,
        transform: Optional[Any] = ...,
        download: bool = ...,
        backend: Optional[Any] = ...,
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...
    def __del__(self) -> None: ...



from __future__ import annotations

from .conll05 import Conll05st as Conll05st
from .imdb import Imdb as Imdb
from .imikolov import Imikolov as Imikolov
from .movielens import Movielens as Movielens
from .uci_housing import UCIHousing as UCIHousing
from .wmt14 import WMT14 as WMT14
from .wmt16 import WMT16 as WMT16



from __future__ import annotations

from typing import Any

from paddle.autograd import EagerPyLayer, PyLayer

logger: Any
formatter: Any
ch: Any

def detach_variable(inputs: Any): ...
def check_recompute_necessary(inputs: Any) -> None: ...
def swith_rng_state(rng_state: Any) -> None: ...

class EagerRecomputeFunction(EagerPyLayer):
    @staticmethod
    def forward(ctx: Any, run_function: Any, preserve_rng_state: Any, *args: Any): ...
    @staticmethod
    def backward(ctx: Any, *args: Any): ...

class RecomputeFunction(PyLayer):
    @staticmethod
    def forward(ctx: Any, run_function: Any, preserve_rng_state: Any, *args: Any): ...
    @staticmethod
    def backward(ctx: Any, *args: Any): ...

def recompute(function: Any, *args: Any, **kwargs: Any): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.framework import Variable as Variable
from paddle.optimizer import Optimizer as Optimizer

from ...base.topology import ParallelMode as ParallelMode
from ...utils.hybrid_parallel_util import (
    fused_allreduce_gradients as fused_allreduce_gradients,
)
from ...utils.hybrid_parallel_util import (
    sharding_reduce_gradients as sharding_reduce_gradients,
)
from ...utils.log_util import logger as logger

class HybridParallelClipGrad:
    def __init__(self, clip: Any, hcg: Any) -> None: ...
    def __getattr__(self, item: Any): ...
    def __call__(self, params_grads: Any): ...

class HybridParallelOptimizer:
    def __init__(self, optimizer: Any, hcg: Any, strategy: Any) -> None: ...
    def step(self) -> None: ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameters: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...
    def __getattr__(self, item: Any): ...



from __future__ import annotations

from typing import Any

class GradientClipHelper:
    mp_ring_id: Any = ...
    def __init__(self, mp_ring_id: Any) -> None: ...
    def prune_gradient_clip(self, block: Any, shard: Any, ring_ids: Any) -> None: ...
    def sync_global_norm(self, block: Any, ring_ids: Any, mp_rank: Any) -> None: ...



from __future__ import annotations

from typing import Any

class Fleet:
    instance_: Any = ...
    fleet_: Any = ...
    def __init__(self) -> None: ...
    def stop(self) -> None: ...
    dist_desc_str_: Any = ...
    dist_desc_: Any = ...
    def init_pserver(self, opt_info: Any) -> None: ...
    def init_worker(self, opt_info: Any) -> None: ...
    def init_pserver_model(self) -> None: ...
    def save_pserver_model(self, save_path: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.backward import gradients_with_optimizer as gradients_with_optimizer

def backward(tensors: Any, grad_tensors: Optional[Any] = ..., retain_graph: bool = ...): ...



from __future__ import annotations

from typing import Any

from ...fluid import dygraph_utils as dygraph_utils
from ...fluid.data_feeder import check_dtype as check_dtype
from ...fluid.layer_helper import LayerHelper as LayerHelper
from ...fluid.layers.layer_function_generator import templatedoc as templatedoc
from ...fluid.layers.sequence_lod import sequence_mask as sequence_mask
from ...static import Variable as Variable
from ...tensor.creation import assign as assign

def diag_embed(input: Any, offset: int = ..., dim1: int = ..., dim2: int = ...): ...



from __future__ import annotations

from typing import Any, Optional

class Initializer:
    def __init__(self) -> None: ...
    def __call__(self, param: Any, block: Optional[Any] = ...) -> None: ...

class ConstantInitializer(Initializer):
    def __init__(self, value: float = ..., force_cpu: bool = ...) -> None: ...
    def __call__(self, var: Any, block: Optional[Any] = ...): ...

class UniformInitializer(Initializer):
    def __init__(
        self,
        low: Any = ...,
        high: float = ...,
        seed: int = ...,
        diag_num: int = ...,
        diag_step: int = ...,
        diag_val: float = ...,
    ) -> None: ...
    def __call__(self, var: Any, block: Optional[Any] = ...): ...

class NormalInitializer(Initializer):
    def __init__(self, loc: float = ..., scale: float = ..., seed: int = ...) -> None: ...
    def __call__(self, var: Any, block: Optional[Any] = ...): ...

class TruncatedNormalInitializer(Initializer):
    def __init__(self, loc: float = ..., scale: float = ..., seed: int = ...) -> None: ...
    def __call__(self, var: Any, block: Optional[Any] = ...): ...

class XavierInitializer(Initializer):
    def __init__(
        self, uniform: bool = ..., fan_in: Optional[Any] = ..., fan_out: Optional[Any] = ..., seed: int = ...
    ) -> None: ...
    def __call__(self, var: Any, block: Optional[Any] = ...): ...

class MSRAInitializer(Initializer):
    def __init__(
        self,
        uniform: bool = ...,
        fan_in: Optional[Any] = ...,
        seed: int = ...,
        negative_slope: int = ...,
        nonlinearity: str = ...,
    ) -> None: ...
    def __call__(self, var: Any, block: Optional[Any] = ...): ...

class BilinearInitializer(Initializer):
    def __init__(self) -> None: ...
    def __call__(self, var: Any, block: Optional[Any] = ...): ...

class NumpyArrayInitializer(Initializer):
    def __init__(self, value: Any) -> None: ...
    def __call__(self, var: Any, block: Optional[Any] = ...): ...

def set_global_initializer(weight_init: Any, bias_init: Optional[Any] = ...) -> None: ...

Constant = ConstantInitializer
Uniform = UniformInitializer
Normal = NormalInitializer
TruncatedNormal = TruncatedNormalInitializer
Xavier = XavierInitializer
MSRA = MSRAInitializer
Bilinear = BilinearInitializer



from __future__ import annotations

from typing import Any

from paddle.fluid.dygraph.dygraph_to_static.origin_info import OriginInfo

ERROR_DATA: str
SIMPLIFY_ERROR_ENV_NAME: str
DEFAULT_SIMPLIFY_NEW_ERROR: int
DISABLE_ERROR_ENV_NAME: str
DEFAULT_DISABLE_NEW_ERROR: int
SOURCE_CODE_RANGE: int
BLANK_COUNT_BEFORE_FILE_STR: int

def attach_error_data(error: Any, in_runtime: bool = ...): ...

class TraceBackFrame(OriginInfo):
    location: Any = ...
    function_name: Any = ...
    source_code: Any = ...
    def __init__(self, location: Any, function_name: Any, source_code: Any) -> None: ...
    def formated_message(self): ...

class TraceBackFrameRange(OriginInfo):
    location: Any = ...
    function_name: Any = ...
    source_code: Any = ...
    def __init__(self, location: Any, function_name: Any) -> None: ...
    def formated_message(self): ...

class SuggestionDict:
    suggestion_dict: Any = ...
    def __init__(self) -> None: ...
    def keys(self): ...
    def __getitem__(self, key: Any): ...

class ErrorData:
    error_type: Any = ...
    error_value: Any = ...
    origin_traceback: Any = ...
    origin_info_map: Any = ...
    in_runtime: bool = ...
    suggestion_dict: Any = ...
    def __init__(self, error_type: Any, error_value: Any, origin_traceback: Any, origin_info_map: Any) -> None: ...
    def create_exception(self): ...
    def create_message(self): ...
    def raise_new_exception(self) -> None: ...



from __future__ import annotations

from typing import Any

from .. import core as core
from .. import layers as layers

def default_collate_fn(batch: Any): ...
def default_convert_fn(batch: Any): ...



from __future__ import annotations

from enum import Enum as Enum
from typing import Any, Optional

logger_: Any

def group_sharded_parallel(
    model: Any,
    optimizer: Any,
    level: Any,
    scaler: Optional[Any] = ...,
    group: Optional[Any] = ...,
    offload: bool = ...,
    sync_buffers: bool = ...,
    buffer_max_size: Any = ...,
    segment_size: Any = ...,
    sync_comm: bool = ...,
): ...
def save_group_sharded_model(model: Any, output: Any, optimizer: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.utils import gast

STATIC_CONVERT_VAR_SHAPE_SUFFIX: str

def create_convert_shape_node(var_shape_node: Any, slice_node: Optional[Any] = ..., in_control_flow: bool = ...): ...
def create_choose_shape_node(attr_shape_name: Any, api_shape_name: Any, slice_node: Optional[Any] = ...): ...

class ShapeAttributeTransformer(gast.NodeTransformer):
    def visit_Attribute(self, node: Any): ...

class TensorShapeTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    name_to_var_shape: Any = ...
    static_analysis_visitor: Any = ...
    node_to_wrapper_map: Any = ...
    scope_var_type_dict: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_Assign(self, node: Any): ...
    def visit_Subscript(self, node: Any): ...
    def visit_Attribute(self, node: Any): ...
    def visit_Name(self, node: Any): ...
    def visit_Call(self, node: Any): ...
    def visit_If(self, node: Any): ...
    def visit_While(self, node: Any): ...
    def visit_For(self, node: Any): ...



from __future__ import annotations

from ...fluid.initializer import ConstantInitializer as ConstantInitializer

class Constant(ConstantInitializer):
    def __init__(self, value: float = ...) -> None: ...



from __future__ import annotations

from typing import Any

from .cluster import DeviceType as DeviceType
from .graph import Edge as Edge
from .graph import Graph as Graph
from .graph import Node as Node
from .process_group import get_process_group as get_process_group

def is_collective_comm_op(op: Any): ...
def is_p2p_comm_op(op: Any): ...
def get_dtype_bytes(dtype: Any): ...
def get_comm_volume(comm_op: Any, src_rank: Any, tgt_rank: Any): ...
def analyze_comm_requirements_from_op(op: Any, rank: Any, g_process_group_map: Any): ...
def analyze_requirements_for_program(src_info: Any, rank: Any): ...
def build_process_graph(distributed_program: Any): ...
def build_cluster_graph(cluster: Any): ...
def mapping(distributed_program: Any, cluster: Any): ...



from __future__ import annotations

from typing import Any, Optional

class Server:
    def __init__(self) -> None: ...

class Worker:
    def __init__(self) -> None: ...

class DownpourServer(Server):
    def __init__(self) -> None: ...
    def add_sparse_table(self, table_id: Any, strategy: Any) -> None: ...
    def add_dense_table(self, table_id: Any, param_var: Any, grad_var: Any, strategy: Any, sparse_table_names: Any): ...
    def add_data_norm_table(
        self, table_id: Any, learning_rate: Any, param_var: Any, grad_var: Any, strategy: Any, sparse_table_names: Any
    ): ...
    def add_sparse_optimizer(self, sgd: Any, strategy: Any, prefix: Any) -> None: ...
    def add_sparse_table_common_config(self, table: Any, strategy: Any) -> None: ...
    def get_desc(self): ...

class DownpourWorker(Worker):
    window: Any = ...
    def __init__(self, window: Any) -> None: ...
    def add_sparse_table(
        self, table_id: Any, slot_key_vars: Any, slot_value_vars: Any, slot_value_grads: Optional[Any] = ...
    ) -> None: ...
    def add_dense_table(
        self,
        table_id: Any,
        learning_rate: Any,
        param_vars: Any,
        grad_vars: Any,
        dense_start_table_id: Any,
        sparse_table_names: Any,
    ) -> None: ...
    def get_desc(self): ...



from __future__ import annotations

from typing import Any, Optional

class FleetUtil:
    op_role_key: Any = ...
    def __init__(self, mode: str = ...) -> None: ...
    def rank0_print(self, s: Any) -> None: ...
    def rank0_info(self, s: Any) -> None: ...
    def rank0_error(self, s: Any) -> None: ...
    def set_zero(self, var_name: Any, scope: Any = ..., place: Any = ..., param_type: str = ...) -> None: ...
    def print_global_auc(
        self, scope: Any = ..., stat_pos: str = ..., stat_neg: str = ..., print_prefix: str = ...
    ) -> None: ...
    def get_global_auc(self, scope: Any = ..., stat_pos: str = ..., stat_neg: str = ...): ...
    def load_fleet_model_one_table(self, table_id: Any, path: Any) -> None: ...
    def load_fleet_model(self, path: Any, mode: int = ...) -> None: ...
    def save_fleet_model(self, path: Any, mode: int = ...) -> None: ...
    def write_model_donefile(
        self,
        output_path: Any,
        day: Any,
        pass_id: Any,
        xbox_base_key: Any,
        hadoop_fs_name: Any,
        hadoop_fs_ugi: Any,
        hadoop_home: str = ...,
        donefile_name: str = ...,
    ) -> None: ...
    def write_xbox_donefile(
        self,
        output_path: Any,
        day: Any,
        pass_id: Any,
        xbox_base_key: Any,
        data_path: Any,
        hadoop_fs_name: Any,
        hadoop_fs_ugi: Any,
        monitor_data: Any = ...,
        hadoop_home: str = ...,
        donefile_name: Optional[Any] = ...,
    ) -> None: ...
    def write_cache_donefile(
        self,
        output_path: Any,
        day: Any,
        pass_id: Any,
        key_num: Any,
        hadoop_fs_name: Any,
        hadoop_fs_ugi: Any,
        hadoop_home: str = ...,
        donefile_name: str = ...,
        **kwargs: Any,
    ) -> None: ...
    def load_model(self, output_path: Any, day: Any, pass_id: Any) -> None: ...
    def save_model(self, output_path: Any, day: Any, pass_id: Any) -> None: ...
    def save_batch_model(self, output_path: Any, day: Any) -> None: ...
    def save_delta_model(self, output_path: Any, day: Any, pass_id: Any) -> None: ...
    def save_xbox_base_model(self, output_path: Any, day: Any) -> None: ...
    def save_cache_model(self, output_path: Any, day: Any, pass_id: Any, mode: int = ..., **kwargs: Any): ...
    def save_cache_base_model(self, output_path: Any, day: Any, **kwargs: Any): ...
    def pull_all_dense_params(self, scope: Any, program: Any) -> None: ...
    def save_paddle_inference_model(
        self,
        executor: Any,
        scope: Any,
        program: Any,
        feeded_vars: Any,
        target_vars: Any,
        output_path: Any,
        day: Any,
        pass_id: Any,
        hadoop_fs_name: Any,
        hadoop_fs_ugi: Any,
        hadoop_home: str = ...,
        save_combine: bool = ...,
    ) -> None: ...
    def save_paddle_params(
        self,
        executor: Any,
        scope: Any,
        program: Any,
        model_name: Any,
        output_path: Any,
        day: Any,
        pass_id: Any,
        hadoop_fs_name: Any,
        hadoop_fs_ugi: Any,
        hadoop_home: str = ...,
        var_names: Optional[Any] = ...,
        save_combine: bool = ...,
    ) -> None: ...
    def get_last_save_xbox_base(
        self, output_path: Any, hadoop_fs_name: Any, hadoop_fs_ugi: Any, hadoop_home: str = ...
    ): ...
    def get_last_save_xbox(self, output_path: Any, hadoop_fs_name: Any, hadoop_fs_ugi: Any, hadoop_home: str = ...): ...
    def get_last_save_model(
        self, output_path: Any, hadoop_fs_name: Any, hadoop_fs_ugi: Any, hadoop_home: str = ...
    ): ...
    def get_online_pass_interval(
        self, days: Any, hours: Any, split_interval: Any, split_per_pass: Any, is_data_hourly_placed: Any
    ): ...
    def get_global_metrics(
        self,
        scope: Any = ...,
        stat_pos_name: str = ...,
        stat_neg_name: str = ...,
        sqrerr_name: str = ...,
        abserr_name: str = ...,
        prob_name: str = ...,
        q_name: str = ...,
        pos_ins_num_name: str = ...,
        total_ins_num_name: str = ...,
    ): ...
    def print_global_metrics(
        self,
        scope: Any = ...,
        stat_pos_name: str = ...,
        stat_neg_name: str = ...,
        sqrerr_name: str = ...,
        abserr_name: str = ...,
        prob_name: str = ...,
        q_name: str = ...,
        pos_ins_num_name: str = ...,
        total_ins_num_name: str = ...,
        print_prefix: str = ...,
    ) -> None: ...
    def program_type_trans(self, prog_dir: Any, prog_fn: Any, is_text: Any): ...
    def draw_from_program_file(
        self, model_filename: Any, is_text: Any, output_dir: Any, output_filename: Any
    ) -> None: ...
    def draw_from_program(self, program: Any, output_dir: Any, output_name: Any) -> None: ...
    def check_two_programs(self, config: Any): ...
    def check_vars_and_dump(self, config: Any): ...
    def parse_program_proto(self, prog_path: Any, is_text: Any, output_dir: Any) -> None: ...
    def split_program_by_device(self, program: Any): ...



from __future__ import annotations

from typing import Any

from . import gast as gast
from .astn import AstToGAst as AstToGAst
from .astn import GAstToAst as GAstToAst

class Ast3ToGAst(AstToGAst):
    def visit_ExtSlice(self, node: Any): ...
    def visit_Index(self, node: Any): ...
    def visit_Module(self, node: Any): ...
    def visit_Num(self, node: Any): ...
    def visit_Ellipsis(self, node: Any): ...
    def visit_Str(self, node: Any): ...
    def visit_Bytes(self, node: Any): ...
    def visit_FunctionDef(self, node: Any): ...
    def visit_AsyncFunctionDef(self, node: Any): ...
    def visit_For(self, node: Any): ...
    def visit_AsyncFor(self, node: Any): ...
    def visit_With(self, node: Any): ...
    def visit_AsyncWith(self, node: Any): ...
    def visit_Call(self, node: Any): ...
    def visit_NameConstant(self, node: Any): ...
    def visit_arguments(self, node: Any): ...
    def visit_Name(self, node: Any): ...
    def visit_arg(self, node: Any): ...
    def visit_ExceptHandler(self, node: Any): ...
    def visit_comprehension(self, node: Any): ...

class GAstToAst3(GAstToAst):
    def visit_Subscript(self, node: Any): ...
    def visit_Module(self, node: Any): ...
    def visit_Constant(self, node: Any): ...
    def visit_Name(self, node: Any): ...
    def visit_ExceptHandler(self, node: Any): ...
    def visit_Call(self, node: Any): ...
    def visit_ClassDef(self, node: Any): ...
    def visit_FunctionDef(self, node: Any): ...
    def visit_AsyncFunctionDef(self, node: Any): ...
    def visit_For(self, node: Any): ...
    def visit_AsyncFor(self, node: Any): ...
    def visit_With(self, node: Any): ...
    def visit_AsyncWith(self, node: Any): ...
    def visit_arguments(self, node: Any): ...

def ast_to_gast(node: Any): ...
def gast_to_ast(node: Any): ...



from __future__ import annotations

from typing import Any, Optional

from .. import Layer as Layer
from .. import functional as functional

class PixelShuffle(Layer):
    def __init__(self, upscale_factor: Any, data_format: str = ..., name: Optional[Any] = ...) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...



from __future__ import annotations

from typing import Any, Optional

class Role:
    WORKER: int = ...
    SERVER: int = ...
    HETER_WORKER: int = ...
    ALL: int = ...

class Gloo:
    class RENDEZVOUS:
        HDFS: int = ...
        FILE: int = ...
        HTTP: int = ...
    def __init__(self) -> None: ...
    def init(
        self,
        rendezvous: Any,
        role: Any,
        role_id: Any,
        worker_num: Any,
        server_num: Any,
        need_init_all: bool = ...,
        kwargs: Optional[Any] = ...,
    ) -> None: ...
    def barrier(self, comm_world: Any) -> None: ...
    def all_reduce(self, input: Any, mode: str = ..., comm_world: str = ...): ...
    def all_gather(self, input: Any, comm_world: str = ...): ...

class RoleMakerBase:
    def __init__(self) -> None: ...
    def to_string(self): ...

class PaddleCloudRoleMaker(RoleMakerBase):
    def __init__(self, is_collective: bool = ..., **kwargs: Any) -> None: ...

class UserDefinedRoleMaker(PaddleCloudRoleMaker):
    def __init__(self, is_collective: bool = ..., init_gloo: bool = ..., **kwargs: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ..fluid.profiler import cuda_profiler as cuda_profiler
from ..fluid.profiler import profiler as profiler
from ..fluid.profiler import reset_profiler as reset_profiler
from ..fluid.profiler import start_profiler as start_profiler
from ..fluid.profiler import stop_profiler as stop_profiler

class ProfilerOptions:
    options: Any = ...
    def __init__(self, options: Optional[Any] = ...) -> None: ...
    def with_state(self, state: Any): ...
    def __getitem__(self, name: Any): ...

class Profiler:
    profiler_options: Any = ...
    batch_id: int = ...
    enabled: Any = ...
    def __init__(self, enabled: bool = ..., options: Optional[Any] = ...) -> None: ...
    previous_profiler: Any = ...
    def __enter__(self): ...
    def __exit__(self, exception_type: Any, exception_value: Any, traceback: Any) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def reset(self) -> None: ...
    def record_step(self, change_profiler_status: bool = ...) -> None: ...

def get_profiler(): ...



from __future__ import annotations

import abc
from typing import Any, Optional

from paddle.io import DataLoader as DataLoader
from paddle.io import DistributedBatchSampler as DistributedBatchSampler

from .utils import to_list as to_list

class DistributedDataLoader(metaclass=abc.ABCMeta):
    dataset: Any = ...
    batch_size: Any = ...
    epochs: Any = ...
    data_parallel_world_size: Any = ...
    data_parallel_rank: Any = ...
    drop_lost: Any = ...
    def __init__(
        self,
        dataset: Any,
        batch_size: int = ...,
        epochs: int = ...,
        data_parallel_world_size: Optional[Any] = ...,
        data_parallel_rank: Optional[Any] = ...,
        drop_last: bool = ...,
    ) -> None: ...
    @abc.abstractmethod
    def __iter__(self) -> Any: ...
    @abc.abstractmethod
    def __next__(self) -> Any: ...

class NonIterableGeneratorLoader(DistributedDataLoader):
    feed_list: Any = ...
    places: Any = ...
    steps_per_epoch: Any = ...
    def __init__(
        self,
        dataset: Any,
        feed_list: Any,
        places: Any,
        batch_size: int = ...,
        epochs: int = ...,
        steps_per_epoch: Optional[Any] = ...,
        data_parallel_world_size: Optional[Any] = ...,
        data_parallel_rank: Optional[Any] = ...,
        drop_last: bool = ...,
        inputs: Any = ...,
    ) -> None: ...
    def __iter__(self) -> Any: ...
    def __next__(self) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.utils import gast

class GradTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_Call(self, node: Any): ...

def is_grad_api_node(node: Any): ...



from __future__ import annotations

from typing import Any

import paddle.fluid as fluid
from paddle.fluid import core as core

def fix_model_dict(model: Any): ...
def pre_hook(layer: Any, input: Any): ...
def post_hook(layer: Any, input: Any, output: Any): ...
def train_lenet(lenet: Any, reader: Any, optimizer: Any): ...

class ImperativeLenet(fluid.dygraph.Layer):
    features: Any = ...
    fc: Any = ...
    add: Any = ...
    quant_stub: Any = ...
    def __init__(self, num_classes: int = ...) -> None: ...
    def forward(self, inputs: Any): ...

class ImperativeLenetWithSkipQuant(fluid.dygraph.Layer):
    conv2d_0: Any = ...
    batch_norm_0: Any = ...
    relu_0: Any = ...
    pool2d_0: Any = ...
    conv2d_1: Any = ...
    batch_norm_1: Any = ...
    relu6_0: Any = ...
    pool2d_1: Any = ...
    linear_0: Any = ...
    leaky_relu_0: Any = ...
    linear_1: Any = ...
    sigmoid_0: Any = ...
    linear_2: Any = ...
    softmax_0: Any = ...
    def __init__(self, num_classes: int = ...) -> None: ...
    def forward(self, inputs: Any): ...

class ImperativeLinearBn(fluid.dygraph.Layer):
    linear: Any = ...
    bn: Any = ...
    def __init__(self) -> None: ...
    def forward(self, inputs: Any): ...

class ImperativeLinearBn_hook(fluid.dygraph.Layer):
    linear: Any = ...
    bn: Any = ...
    def __init__(self) -> None: ...
    def forward(self, inputs: Any): ...



from __future__ import annotations

from typing import Any, Optional

from ..base.private_helper_function import wait_server_ready as wait_server_ready

OpRole: Any
OP_ROLE_KEY: Any
OP_ROLE_VAR_KEY: Any

def is_update_op(op: Any): ...
def is_loss_grad_op(op: Any): ...
def is_backward_op(op: Any): ...
def is_optimizer_op(op: Any): ...

class CollectiveHelper:
    nrings: Any = ...
    wait_port: Any = ...
    role_maker: Any = ...
    def __init__(self, role_maker: Any, nrings: int = ..., wait_port: bool = ...) -> None: ...
    startup_program: Any = ...
    def update_startup_program(self, startup_program: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.fluid.dygraph.dygraph_to_static.utils import BaseNodeVisitor
from paddle.utils import gast

class ForToWhileTransformer(gast.NodeTransformer):
    parent_node: Any = ...
    loop_node: Any = ...
    condition_node: Any = ...
    def __init__(self, parent_node: Any, loop_node: Any, condition_node: Any) -> None: ...
    def transform(self): ...
    def get_for_stmt_nodes(self, node: Any): ...

class BreakContinueTransformer(BaseNodeVisitor):
    wrapper_root: Any = ...
    root: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_Break(self, node: Any) -> None: ...
    def visit_Continue(self, node: Any) -> None: ...

class BreakTransformOptimizer(BaseNodeVisitor):
    wrapper_root: Any = ...
    root: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_Break(self, node: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

COMM_OP_TYPE: Any
NON_COMP_TYPE: Any
OP_COST_FACTORY: Any

def parse_to_desc(op: Optional[Any] = ..., dist_op: Optional[Any] = ..., dist_context: Optional[Any] = ...): ...
def parse_desc_to_str(desc: Any): ...

class CommContext:
    cluster: Any = ...
    def __init__(self, cluster: Any) -> None: ...
    def __new__(cls, *args: Any, **kwargs: Any): ...
    @property
    def alpha_inter(self): ...
    @property
    def alpha_intra(self): ...
    @property
    def alpha_base_ring(self): ...
    @property
    def alpha_base_tree(self): ...
    def get_beta(self, ranks: Any): ...

class Cost:
    def __init__(self, time: int = ..., memory: int = ..., flops: int = ...) -> None: ...
    @property
    def time(self): ...
    @time.setter
    def time(self, val: Any) -> None: ...
    @property
    def memory(self): ...
    @memory.setter
    def memory(self, val: Any) -> None: ...
    @property
    def flops(self): ...
    @flops.setter
    def flops(self, val: Any) -> None: ...
    def __add__(self, rhs: Any): ...
    def __sub__(self, rhs: Any): ...

class OpCost:
    def __init__(self, op: Optional[Any] = ..., op_desc: Optional[Any] = ...) -> None: ...
    @property
    def op(self): ...
    @property
    def op_desc(self): ...
    @property
    def cost(self): ...
    def calc_time(self): ...
    def calc_memory(self): ...
    def calc_flops(self): ...
    def calc_cost(self): ...

class CommOpCost(OpCost):
    OP_TYPE: str = ...
    def __init__(
        self, op: Optional[Any] = ..., op_desc: Optional[Any] = ..., comm_context: Optional[Any] = ...
    ) -> None: ...
    @property
    def comm_context(self): ...

class CompOpCost(OpCost):
    OP_TYPE: str = ...
    cluster: Any = ...
    def __init__(self, op: Optional[Any] = ..., op_desc: Optional[Any] = ..., cluster: Optional[Any] = ...) -> None: ...

def register_op_cost(cls): ...
def calc_time_from_model(
    op: Optional[Any] = ..., desc: Optional[Any] = ..., cluster: Optional[Any] = ..., comm_context: Optional[Any] = ...
): ...



from __future__ import annotations

from typing import Any

class Index:
    def __init__(self, name: Any) -> None: ...

class TreeIndex(Index):
    def __init__(self, name: Any, path: Any) -> None: ...
    def height(self): ...
    def branch(self): ...
    def total_node_nums(self): ...
    def emb_size(self): ...
    def get_all_leafs(self): ...
    def get_nodes(self, codes: Any): ...
    def get_layer_codes(self, level: Any): ...
    def get_travel_codes(self, id: Any, start_level: int = ...): ...
    def get_ancestor_codes(self, ids: Any, level: Any): ...
    def get_children_codes(self, ancestor: Any, level: Any): ...
    def get_travel_path(self, child: Any, ancestor: Any): ...
    def get_pi_relation(self, ids: Any, level: Any): ...
    def init_layerwise_sampler(
        self, layer_sample_counts: Any, start_sample_layer: int = ..., seed: int = ...
    ) -> None: ...
    def layerwise_sample(self, user_input: Any, index_input: Any, with_hierarchy: bool = ...): ...



from __future__ import annotations

from typing import Any, Optional

class Quant2Int8MkldnnPass:
    def __init__(
        self,
        _ops_to_quantize: Any,
        _op_ids_to_skip: Optional[Any] = ...,
        _scope: Optional[Any] = ...,
        _place: Optional[Any] = ...,
        _core: Optional[Any] = ...,
        _debug: bool = ...,
    ) -> None: ...
    def apply(self, graph: Any): ...
    def prepare_and_optimize_fp32(self, graph: Any): ...



from __future__ import annotations

from . import imperative as imperative
from . import post_training_quantization as post_training_quantization
from . import quant2_int8_mkldnn_pass as quant2_int8_mkldnn_pass
from . import quant_int8_mkldnn_pass as quant_int8_mkldnn_pass
from . import quantization_pass as quantization_pass
from .imperative import *
from .post_training_quantization import *
from .quant2_int8_mkldnn_pass import *
from .quant_int8_mkldnn_pass import *
from .quantization_pass import *



from __future__ import annotations

from .mp_layers import ColumnParallelLinear as ColumnParallelLinear
from .mp_layers import ParallelCrossEntropy as ParallelCrossEntropy
from .mp_layers import RowParallelLinear as RowParallelLinear
from .mp_layers import VocabParallelEmbedding as VocabParallelEmbedding
from .pp_layers import LayerDesc as LayerDesc
from .pp_layers import PipelineLayer as PipelineLayer
from .pp_layers import SharedLayerDesc as SharedLayerDesc
from .random import RNGStatesTracker as RNGStatesTracker
from .random import get_rng_state_tracker as get_rng_state_tracker
from .random import model_parallel_random_seed as model_parallel_random_seed



from __future__ import annotations

from typing import Any, Optional

def softshrink(x: Any, alpha: Optional[Any] = ...): ...
def hard_shrink(x: Any, threshold: Optional[Any] = ...): ...
def cumsum(x: Any, axis: Optional[Any] = ..., exclusive: Optional[Any] = ..., reverse: Optional[Any] = ...): ...
def thresholded_relu(x: Any, threshold: Optional[Any] = ...): ...
def gelu(x: Any, approximate: bool = ...): ...
def erf(x: Any, name: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

logger: Any

class DistributeMode:
    COLLECTIVE: int = ...
    PS: int = ...
    PS_HETER: int = ...

class DeviceMode:
    UNKNOWN: int = ...
    CPU: int = ...
    GPU: int = ...
    KUNLUN: int = ...
    XPU: int = ...
    ASCEND_NPU: int = ...
    MLU: int = ...

class Cluster:
    job_server: Any = ...
    pods: Any = ...
    hdfs: Any = ...
    job_stage_flag: Any = ...
    def __init__(self, hdfs: Any) -> None: ...
    def __eq__(self, cluster: Any) -> Any: ...
    def __ne__(self, cluster: Any) -> Any: ...
    def update_pods(self, cluster: Any) -> None: ...
    def trainers_nranks(self): ...
    def pods_nranks(self): ...
    def trainers_endpoints(self): ...
    def world_device_ids(self): ...
    def pods_endpoints(self): ...
    def get_pod_by_id(self, pod_id: Any): ...

class JobServer:
    endpoint: Any = ...
    def __init__(self) -> None: ...
    def __eq__(self, j: Any) -> Any: ...
    def __ne__(self, j: Any) -> Any: ...

class Trainer:
    accelerators: Any = ...
    endpoint: Any = ...
    stage: Any = ...
    def __init__(self) -> None: ...
    def __eq__(self, t: Any) -> Any: ...
    def __ne__(self, t: Any) -> Any: ...
    def rank(self): ...

class Pod:
    id: Any = ...
    addr: Any = ...
    port: Any = ...
    trainers: Any = ...
    servers: Any = ...
    workers: Any = ...
    heter_workers: Any = ...
    accelerators: Any = ...
    device_mode: Any = ...
    def __init__(self) -> None: ...
    def __eq__(self, pod: Any) -> Any: ...
    def __ne__(self, pod: Any) -> Any: ...
    def parse_response(self, res_pods: Any) -> None: ...
    def rank(self): ...
    def get_visible_accelerators(self): ...

def get_logger(log_level: int = ..., name: str = ...): ...
def get_cluster(node_ips: Any, node_ip: Any, trainer_endpoints: Any, device_mode: Any, devices_per_proc: Any): ...
def terminate_local_procs(procs: Any) -> None: ...
def get_host_name_ip(): ...
def add_arguments(argname: Any, type: Any, default: Any, help: Any, argparser: Any, **kwargs: Any) -> None: ...
def find_free_ports(num: Any): ...
def get_ports(num: Any, offset: Any): ...
def pretty_print_envs(envs: Any, header: Optional[Any] = ...): ...

class TrainerProc:
    proc: Any = ...
    log_fn: Any = ...
    log_offset: Any = ...
    rank: Any = ...
    local_rank: Any = ...
    cmd: Any = ...
    def __init__(self) -> None: ...

def run_with_coverage(*args: Any): ...
def start_local_trainers(
    cluster: Any,
    pod: Any,
    training_script: Any,
    training_script_args: Any,
    log_dir: Optional[Any] = ...,
    envs: Optional[Any] = ...,
): ...
def pull_worker_log(tp: Any) -> None: ...
def watch_local_trainers(procs: Any, nranks: Any): ...
def get_gpus(gpus: Any): ...
def get_xpus(xpus: Any): ...
def get_npus(npus: Any): ...
def get_mlus(mlus: Any): ...
def get_device_mode(backend: Any): ...
def get_device_proc_info(args: Any): ...
def direct_start(args: Any) -> None: ...
def get_custom_endpoints(origin_endpoints: Any, offset: int = ...): ...
def get_mapped_cluster_without_rank_mapping(
    node_ips: Any, node_ip: Any, trainer_endpoints: Any, device_mode: Any, node_ranks: Any
): ...
def get_mapped_cluster_from_args_without_rank_mapping(args: Any, device_mode: Any): ...
def get_mapped_cluster_with_rank_mapping(
    node_ips: Any, node_ip: Any, trainer_endpoints: Any, device_mode: Any, node_ranks: Any, node_rank_mappings: Any
): ...
def get_mapped_cluster_from_args_with_rank_mapping(args: Any, device_mode: Any): ...

class ParameterServerLauncher:
    args: Any = ...
    distribute_mode: Any = ...
    server_num: int = ...
    worker_num: int = ...
    heter_worker_num: int = ...
    server_endpoints: str = ...
    server_endpoints_ips: Any = ...
    server_endpoints_port: Any = ...
    worker_endpoints: str = ...
    worker_endpoints_ips: Any = ...
    worker_endpoints_port: Any = ...
    heter_worker_endpoints: str = ...
    heter_worker_endpoints_ips: Any = ...
    heter_worker_endpoints_port: Any = ...
    is_local: bool = ...
    current_node_ip: str = ...
    stage_trainer_num: Any = ...
    stage_heter_map: Any = ...
    stage_list: Any = ...
    stage_device_map: Any = ...
    stage_num: int = ...
    def __init__(self, args: Any, distribute_mode: Any) -> None: ...
    stage_heter_trainer_num: Any = ...
    http_port: Any = ...
    node_ips: Any = ...
    node_rank: Any = ...
    def get_role_endpoints(self, args: Any) -> None: ...
    gloo_rendezvous_dir: Any = ...
    procs: Any = ...
    cmds: Any = ...
    log_fns: Any = ...
    def start_ps(self) -> None: ...
    def start_pod_server(self, args: Any, pod: Any) -> None: ...
    def start_pod_worker(self, args: Any, pod: Any) -> None: ...
    def start_pod_heter_worker(self, args: Any, pod: Any) -> None: ...

def check_backend(backend: Any) -> None: ...
def block_windows_and_macos(backend: Any) -> None: ...
def get_backend_by_compile_flag(): ...



from __future__ import annotations

from typing import Any, Optional

dtype_to_size: Any

class VarBlock:
    varname: Any = ...
    offset: Any = ...
    size: Any = ...
    def __init__(self, varname: Any, offset: Any, size: Any) -> None: ...

def create_var_struct(var: Any): ...

class VarStruct:
    name: Any = ...
    shape: Any = ...
    dtype: Any = ...
    type: Any = ...
    lod_level: Any = ...
    persistable: Any = ...
    m_size: int = ...
    def __init__(self, name: Any, shape: Any, dtype: Any, type: Any, lod_level: Any, persistable: Any): ...

class VarDistributed:
    origin: Any = ...
    slice: Any = ...
    is_slice: bool = ...
    block_id: int = ...
    offset: int = ...
    vtype: Any = ...
    endpoint: Any = ...
    def __init__(
        self,
        origin_var: Any,
        slice_var: Any,
        is_slice: Optional[Any] = ...,
        block_id: Optional[Any] = ...,
        offset: Optional[Any] = ...,
        vtype: Optional[Any] = ...,
        endpoint: Optional[Any] = ...,
    ) -> None: ...
    @staticmethod
    def equal(var1: Any, var2: Any): ...

class VarsDistributed:
    distributed_vars: Any = ...
    def __init__(self) -> None: ...
    def add_distributed_var(
        self,
        origin_var: Any,
        slice_var: Any,
        is_slice: Optional[Any] = ...,
        block_id: Optional[Any] = ...,
        offset: Optional[Any] = ...,
        vtype: Optional[Any] = ...,
        endpoint: Optional[Any] = ...,
    ) -> None: ...



from __future__ import annotations

from typing import Any, Optional

class TaskNode:
    previous: Any = ...
    node: Any = ...
    program: Any = ...
    def __init__(
        self,
        cur_rank: Any,
        max_run_times: Any,
        max_slot_times: Any,
        role: Optional[Any] = ...,
        node_type: str = ...,
        task_id: Optional[Any] = ...,
        ops: Optional[Any] = ...,
        program: Optional[Any] = ...,
    ) -> None: ...
    def set_type(self, interceptor_type: Any) -> None: ...
    def task_node(self): ...
    def set_program(self, program: Any) -> None: ...
    def get_program(self): ...
    def set_run_pre_steps(self, steps: Any) -> None: ...
    def set_run_at_offset(self, offset: Any) -> None: ...
    def add_upstream_task(self, upstream: Any, buffer_size: Any) -> None: ...
    def add_downstream_task(self, downstream: Any, buffer_size: Any) -> None: ...
    def role(self): ...
    def task_id(self): ...

class CoordSys:
    dp_degree: Any = ...
    pp_degree: Any = ...
    sharding_degree: Any = ...
    mp_degree: Any = ...
    def __init__(self, dist_opt: Any) -> None: ...
    def coord_to_rank(self, coord: Any): ...
    def rank_to_coord(self, rank: Any): ...

def is_optimizer_op(op_role: Any): ...
def is_lr_sched_op(op_role: Any): ...
def is_forward_op(op_role: Any): ...
def is_backward_op(op_role: Any): ...
def run1f1b(program: Any, cur_rank: Any, max_run_times: Any, dist_opt: Any, nrank: Any): ...
def origin(program: Any, cur_rank: Any): ...



from __future__ import annotations

from typing import Any, Optional

class Sampler:
    data_source: Any = ...
    def __init__(self, data_source: Optional[Any] = ...) -> None: ...
    def __iter__(self) -> Any: ...

class SequenceSampler(Sampler):
    data_source: Any = ...
    def __init__(self, data_source: Any) -> None: ...
    def __iter__(self) -> Any: ...
    def __len__(self): ...

class RandomSampler(Sampler):
    data_source: Any = ...
    replacement: Any = ...
    generator: Any = ...
    def __init__(
        self,
        data_source: Any,
        replacement: bool = ...,
        num_samples: Optional[Any] = ...,
        generator: Optional[Any] = ...,
    ) -> None: ...
    @property
    def num_samples(self): ...
    def __iter__(self) -> Any: ...
    def __len__(self): ...

class WeightedRandomSampler(Sampler):
    weights: Any = ...
    num_samples: Any = ...
    replacement: Any = ...
    def __init__(self, weights: Any, num_samples: Any, replacement: bool = ...) -> None: ...
    def __iter__(self) -> Any: ...
    def __len__(self): ...



from __future__ import annotations

from typing import Any

from .pass_base import PassBase as PassBase
from .pass_base import register_pass as register_pass

world_process_group: Any

class AMPState:
    def __init__(self, block: Any) -> None: ...
    def cast_forward_program(self, dist_context: Any) -> None: ...
    def cast_backward_program(self, params_grads: Any, dist_context: Any) -> None: ...

class AMPPass(PassBase):
    def __init__(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def set_excluded_layers(main_program: Any, param_names: Any) -> None: ...
def reset_excluded_layers(main_program: Optional[Any] = ...) -> None: ...
def decorate(optimizer: Any): ...
def prune_model(
    main_program: Optional[Any] = ..., n: int = ..., m: int = ..., mask_algo: str = ..., with_mask: bool = ...
): ...

class ProgramASPInfo:
    def __init__(self) -> None: ...
    def update_mask_vars(self, param_name: Any, var: Any) -> None: ...
    def update_masks(self, param_name: Any, var: Any) -> None: ...
    def update_excluded_layers(self, param_names: Any) -> None: ...
    def reset_excluded_layers(self) -> None: ...
    @property
    def mask_vars(self): ...
    @property
    def masks(self): ...
    @property
    def excluded_layers(self): ...

class ASPHelper:
    MASK_APPENDDED_NAME: str = ...
    PADDLE_WEIGHT_SUFFIX: str = ...
    @classmethod
    def set_excluded_layers(cls, main_program: Any, param_names: Any) -> None: ...
    @classmethod
    def reset_excluded_layers(cls, main_program: Optional[Any] = ...) -> None: ...
    @staticmethod
    def decorate(optimizer: Any): ...
    @classmethod
    def prune_model(
        cls,
        place: Any,
        main_program: Optional[Any] = ...,
        n: int = ...,
        m: int = ...,
        mask_algo: Any = ...,
        with_mask: bool = ...,
    ): ...

class OptimizerWithSparsityGuarantee:
    def __init__(self, optimizer: Any) -> None: ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...



from __future__ import annotations

from .profiler import Profiler as Profiler
from .profiler import ProfilerState as ProfilerState
from .profiler import ProfilerTarget as ProfilerTarget
from .profiler import export_chrome_tracing as export_chrome_tracing
from .profiler import export_protobuf as export_protobuf
from .profiler import make_scheduler as make_scheduler
from .profiler_statistic import SortedKeys as SortedKeys
from .utils import RecordEvent as RecordEvent
from .utils import load_profiler_result as load_profiler_result



from __future__ import annotations

from typing import Any, Optional

from .common import OP_ROLE_KEY as OP_ROLE_KEY
from .common import CollectiveHelper as CollectiveHelper
from .common import OpRole as OpRole
from .common import is_update_op as is_update_op
from .meta_optimizer_base import MetaOptimizerBase as MetaOptimizerBase

class LocalSGDOptimizer(MetaOptimizerBase):
    inner_opt: Any = ...
    meta_optimizers_white_list: Any = ...
    meta_optimizers_black_list: Any = ...
    snapshot_key: str = ...
    def __init__(self, optimizer: Any) -> None: ...
    def snapshot_name(self, param_name: Any): ...
    def create_snapshot_vars(self, program: Any): ...
    def init_snapshot_vars(self, startup_program: Any, param2snapshot: Any) -> None: ...
    nrings: int = ...
    def minimize_impl(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...

class AdaptiveLocalSGDOptimizer(MetaOptimizerBase):
    inner_opt: Any = ...
    meta_optimizers_white_list: Any = ...
    meta_optimizers_black_list: Any = ...
    snapshot_key: str = ...
    def __init__(self, optimizer: Any) -> None: ...
    def snapshot_name(self, param_name: Any): ...
    def create_snapshot_vars(self, program: Any): ...
    def init_snapshot_vars(self, startup_program: Any, param2snapshot: Any) -> None: ...
    nrings: int = ...
    def minimize_impl(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...



from __future__ import annotations

from typing import Any

from .collective import CollectiveController as CollectiveController
from .collective import CollectiveElasticController as CollectiveElasticController
from .ps import PSController as PSController

def init(ctx: Any): ...



from __future__ import annotations

from typing import Any, Optional

interpreter: Any
import_cv2_proc: Any
out: Any
err: Any
retcode: Any
cv2: Any

def batch_images_from_tar(data_file: Any, dataset_name: Any, img2label: Any, num_per_batch: int = ...): ...
def load_image_bytes(bytes: Any, is_color: bool = ...): ...
def load_image(file: Any, is_color: bool = ...): ...
def resize_short(im: Any, size: Any): ...
def to_chw(im: Any, order: Any = ...): ...
def center_crop(im: Any, size: Any, is_color: bool = ...): ...
def random_crop(im: Any, size: Any, is_color: bool = ...): ...
def left_right_flip(im: Any, is_color: bool = ...): ...
def simple_transform(
    im: Any, resize_size: Any, crop_size: Any, is_train: Any, is_color: bool = ..., mean: Optional[Any] = ...
): ...
def load_and_transform(
    filename: Any, resize_size: Any, crop_size: Any, is_train: Any, is_color: bool = ..., mean: Optional[Any] = ...
): ...



from __future__ import annotations

from ..fluid.framework import require_version as require_version
from .deprecated import deprecated as deprecated
from .install_check import run_check as run_check
from .lazy_import import try_import as try_import



from __future__ import annotations

from typing import Any, Optional

from ...fluid.initializer import MSRAInitializer as MSRAInitializer

class KaimingNormal(MSRAInitializer):
    def __init__(self, fan_in: Optional[Any] = ..., negative_slope: float = ..., nonlinearity: str = ...) -> None: ...

class KaimingUniform(MSRAInitializer):
    def __init__(self, fan_in: Optional[Any] = ..., negative_slope: float = ..., nonlinearity: str = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

class tqdm:
    total: Any = ...
    n: int = ...
    def __init__(self, total: Optional[Any] = ...) -> None: ...
    def update(self, n: Any) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None: ...

def get_weights_path_from_url(url: Any, md5sum: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.dygraph.dygraph_to_static.logging_utils import (
    set_code_level as set_code_level,
)
from paddle.fluid.dygraph.dygraph_to_static.logging_utils import (
    set_verbosity as set_verbosity,
)

dygraph_to_static_func: Any

def declarative(
    function: Optional[Any] = ..., input_spec: Optional[Any] = ..., build_strategy: Optional[Any] = ...
): ...
def not_to_static(func: Optional[Any] = ...): ...

class _SaveLoadConfig:
    with_hook: bool = ...
    def __init__(self) -> None: ...
    @property
    def output_spec(self): ...
    @output_spec.setter
    def output_spec(self, spec: Any) -> None: ...
    @property
    def model_filename(self): ...
    @model_filename.setter
    def model_filename(self, filename: Any) -> None: ...
    @property
    def params_filename(self): ...
    @params_filename.setter
    def params_filename(self, filename: Any) -> None: ...
    @property
    def keep_name_table(self): ...
    @keep_name_table.setter
    def keep_name_table(self, value: Any) -> None: ...

class HookRemoveHelper:
    def __init__(self, hook: Any) -> None: ...
    def remove(self) -> None: ...

def save(layer: Any, path: Any, input_spec: Optional[Any] = ..., **configs: Any) -> None: ...
def load(path: Any, **configs: Any): ...

class TracedLayer:
    def __init__(self, program: Any, parameters: Any, feed_names: Any, fetch_names: Any) -> None: ...
    @property
    def program(self): ...
    @staticmethod
    def trace(layer: Any, inputs: Any): ...
    def set_strategy(self, build_strategy: Optional[Any] = ..., exec_strategy: Optional[Any] = ...) -> None: ...
    def __call__(self, inputs: Any): ...
    def save_inference_model(self, path: Any, feed: Optional[Any] = ..., fetch: Optional[Any] = ..., **kwargs: Any): ...



from __future__ import annotations

from typing import Any, Optional

import paddle.fluid as fluid
from paddle.fluid.compiler import CompiledProgram as CompiledProgram
from paddle.fluid.incubate.fleet.base.fleet_base import DistributedOptimizer, Fleet
from paddle.fluid.parallel_executor import ParallelExecutor as ParallelExecutor

class LambConfig:
    def __init__(self) -> None: ...

class DistFCConfig:
    def __init__(self) -> None: ...

class Collective(Fleet):
    startup_program: Any = ...
    main_program: Any = ...
    def __init__(self) -> None: ...
    def init_worker(self) -> None: ...
    def run_worker(self, main_programs: Optional[Any] = ..., scopes: Optional[Any] = ...) -> None: ...
    def init_server(self, model_dir: Optional[Any] = ...) -> None: ...
    def run_server(self) -> None: ...
    def stop_worker(self) -> None: ...
    def distributed_optimizer(self, optimizer: Any, strategy: Optional[Any] = ...): ...
    def save_inference_model(
        self,
        executor: Any,
        dirname: Any,
        feeded_var_names: Optional[Any] = ...,
        target_vars: Optional[Any] = ...,
        main_program: Optional[Any] = ...,
        export_for_deployment: bool = ...,
    ) -> None: ...
    def save_persistables(
        self, executor: Any, dirname: Any, main_program: Optional[Any] = ..., filename: Optional[Any] = ...
    ) -> None: ...
    def save_checkpoint(
        self,
        executor: Any,
        path: Any,
        trainer_id: Any,
        train_status: Any,
        fs: Any,
        main_program: Optional[Any] = ...,
        local_cache_path: str = ...,
        remain_all_checkpoint: bool = ...,
    ): ...
    def load_checkpoint(
        self,
        executor: Any,
        path: Any,
        trainer_id: Any,
        train_status: Any,
        fs: Any,
        main_program: Optional[Any] = ...,
        local_cache_path: str = ...,
        ignore_empty: bool = ...,
    ): ...

fleet: Any

class DistributedStrategy(fluid.BuildStrategy):
    use_local_sgd: bool = ...
    use_dist_fc: bool = ...
    dist_fc_config: Any = ...
    mode: str = ...
    collective_mode: Any = ...
    nccl_comm_num: int = ...
    forward_recompute: bool = ...
    recompute_checkpoints: Any = ...
    use_amp: bool = ...
    amp_loss_scaling: Any = ...
    exec_strategy: Any = ...
    def __init__(self) -> None: ...

class CollectiveOpBasedOptimizer(DistributedOptimizer):
    def __init__(self, optimizer: Any, strategy: Optional[Any] = ...) -> None: ...
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ): ...
    def apply_gradients(self, params_grads: Any): ...

class CollectiveOptimizer(DistributedOptimizer):
    print_config: bool = ...
    def __init__(self, optimizer: Any, strategy: Any = ...) -> None: ...
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ): ...
    def apply_gradients(self, params_grads: Any): ...
    def raiseOptimizeError(self, strategy_name: Any, optimize_name: Any) -> None: ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...



from __future__ import annotations

from typing import Any, Optional

def set_resnet_unit_attrs(resnet_unit: Any, has_shortcut: Any) -> None: ...
def set_resnet_unit_outputs(
    resnet_unit: Any, meanX: Any, varX: Any, meanZ: Optional[Any] = ..., varZ: Optional[Any] = ...
) -> None: ...
def fuse_resnet_unit(): ...



from __future__ import annotations

import abc
from typing import Any, Optional

from ..fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..fluid.framework import core as core
from ..fluid.layer_helper import LayerHelper as LayerHelper

class Metric(metaclass=abc.ABCMeta):
    def __init__(self) -> None: ...
    @abc.abstractmethod
    def reset(self) -> Any: ...
    @abc.abstractmethod
    def update(self, *args: Any) -> Any: ...
    @abc.abstractmethod
    def accumulate(self) -> Any: ...
    @abc.abstractmethod
    def name(self) -> Any: ...
    def compute(self, *args: Any): ...

class Accuracy(Metric):
    topk: Any = ...
    maxk: Any = ...
    def __init__(self, topk: Any = ..., name: Optional[Any] = ..., *args: Any, **kwargs: Any) -> None: ...
    def compute(self, pred: Any, label: Any, *args: Any): ...
    def update(self, correct: Any, *args: Any): ...
    total: Any = ...
    count: Any = ...
    def reset(self) -> None: ...
    def accumulate(self): ...
    def name(self): ...

class Precision(Metric):
    tp: int = ...
    fp: int = ...
    def __init__(self, name: str = ..., *args: Any, **kwargs: Any) -> None: ...
    def update(self, preds: Any, labels: Any) -> None: ...
    def reset(self) -> None: ...
    def accumulate(self): ...
    def name(self): ...

class Recall(Metric):
    tp: int = ...
    fn: int = ...
    def __init__(self, name: str = ..., *args: Any, **kwargs: Any) -> None: ...
    def update(self, preds: Any, labels: Any) -> None: ...
    def accumulate(self): ...
    def reset(self) -> None: ...
    def name(self): ...

class Auc(Metric):
    def __init__(
        self, curve: str = ..., num_thresholds: int = ..., name: str = ..., *args: Any, **kwargs: Any
    ) -> None: ...
    def update(self, preds: Any, labels: Any) -> None: ...
    @staticmethod
    def trapezoid_area(x1: Any, x2: Any, y1: Any, y2: Any): ...
    def accumulate(self): ...
    def reset(self) -> None: ...
    def name(self): ...

def accuracy(
    input: Any,
    label: Any,
    k: int = ...,
    correct: Optional[Any] = ...,
    total: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from ..fluid.dataloader import BatchSampler as BatchSampler
from ..fluid.dataloader import ChainDataset as ChainDataset
from ..fluid.dataloader import ComposeDataset as ComposeDataset
from ..fluid.dataloader import Dataset as Dataset
from ..fluid.dataloader import DistributedBatchSampler as DistributedBatchSampler
from ..fluid.dataloader import IterableDataset as IterableDataset
from ..fluid.dataloader import RandomSampler as RandomSampler
from ..fluid.dataloader import Sampler as Sampler
from ..fluid.dataloader import SequenceSampler as SequenceSampler
from ..fluid.dataloader import Subset as Subset
from ..fluid.dataloader import TensorDataset as TensorDataset
from ..fluid.dataloader import WeightedRandomSampler as WeightedRandomSampler
from ..fluid.dataloader import get_worker_info as get_worker_info
from ..fluid.dataloader import random_split as random_split
from ..fluid.io import DataLoader as DataLoader



from __future__ import annotations

from typing import Any, Optional

class VarStruct:
    name: Any = ...
    shape: Any = ...
    dtype: Any = ...
    type: Any = ...
    lod_level: Any = ...
    persistable: Any = ...
    def __init__(self, name: Any, shape: Any, dtype: Any, type: Any, lod_level: Any, persistable: Any) -> None: ...

class VarDistributed:
    origin: Any = ...
    slice: Any = ...
    is_slice: bool = ...
    block_id: int = ...
    offset: int = ...
    vtype: Any = ...
    endpoint: Any = ...
    def __init__(
        self,
        origin_var: Any,
        slice_var: Any,
        is_slice: Optional[Any] = ...,
        block_id: Optional[Any] = ...,
        offset: Optional[Any] = ...,
        vtype: Optional[Any] = ...,
        endpoint: Optional[Any] = ...,
    ) -> None: ...
    @staticmethod
    def equal(var1: Any, var2: Any): ...

class VarsDistributed:
    distributed_vars: Any = ...
    def __init__(self) -> None: ...
    def add_distributed_var(
        self,
        origin_var: Any,
        slice_var: Any,
        is_slice: Optional[Any] = ...,
        block_id: Optional[Any] = ...,
        offset: Optional[Any] = ...,
        vtype: Optional[Any] = ...,
        endpoint: Optional[Any] = ...,
    ) -> None: ...
    def get_distributed_var_by_slice(self, var_name: Any): ...
    @staticmethod
    def equal(var1: Any, var2: Any): ...
    def get_distributed_var_by_origin_and_ep(self, origin_var_name: Any, endpoint: Any): ...
    def get_distributed_vars_by_vtypes(self, vtypes: Any, groupby: bool = ...): ...
    def get_distributed_vars_by_ep(self, endpoint: Any, vtype: Optional[Any] = ...): ...
    def overview(self): ...



from __future__ import annotations

from typing import Any, Optional

class Dataset:
    def __init__(self) -> None: ...
    def __getitem__(self, idx: Any) -> None: ...
    def __len__(self) -> None: ...

class IterableDataset(Dataset):
    def __init__(self) -> None: ...
    def __iter__(self) -> Any: ...
    def __getitem__(self, idx: Any) -> None: ...
    def __len__(self) -> None: ...

class TensorDataset(Dataset):
    tensors: Any = ...
    def __init__(self, tensors: Any) -> None: ...
    def __getitem__(self, index: Any): ...
    def __len__(self): ...

class ComposeDataset(Dataset):
    datasets: Any = ...
    def __init__(self, datasets: Any) -> None: ...
    def __len__(self): ...
    def __getitem__(self, idx: Any): ...

class ChainDataset(IterableDataset):
    datasets: Any = ...
    def __init__(self, datasets: Any) -> None: ...
    def __iter__(self) -> Any: ...

class Subset(Dataset):
    dataset: Any = ...
    indices: Any = ...
    def __init__(self, dataset: Any, indices: Any) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...

def random_split(dataset: Any, lengths: Any, generator: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

from ..fluid.data_feeder import check_type as check_type
from ..fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..fluid.framework import in_dygraph_mode as in_dygraph_mode
from ..fluid.layer_helper import LayerHelper as LayerHelper
from ..fluid.layers import is_empty as is_empty
from ..fluid.layers import logical_and as logical_and
from ..fluid.layers import logical_not as logical_not
from ..fluid.layers import logical_or as logical_or
from ..fluid.layers import logical_xor as logical_xor
from ..fluid.layers.layer_function_generator import templatedoc as templatedoc
from ..static import Variable as Variable

Tensor: Any

def equal_all(x: Any, y: Any, name: Optional[Any] = ...): ...
def allclose(
    x: Any, y: Any, rtol: float = ..., atol: float = ..., equal_nan: bool = ..., name: Optional[Any] = ...
): ...
def equal(x: Any, y: Any, name: Optional[Any] = ...): ...
def greater_equal(x: Any, y: Any, name: Optional[Any] = ...): ...
def greater_than(x: Any, y: Any, name: Optional[Any] = ...): ...
def less_equal(x: Any, y: Any, name: Optional[Any] = ...): ...
def less_than(x: Any, y: Any, name: Optional[Any] = ...): ...
def not_equal(x: Any, y: Any, name: Optional[Any] = ...): ...
def is_tensor(x: Any): ...
def bitwise_and(x: Any, y: Any, out: Optional[Any] = ..., name: Optional[Any] = ...): ...
def bitwise_or(x: Any, y: Any, out: Optional[Any] = ..., name: Optional[Any] = ...): ...
def bitwise_xor(x: Any, y: Any, out: Optional[Any] = ..., name: Optional[Any] = ...): ...
def bitwise_not(x: Any, out: Optional[Any] = ..., name: Optional[Any] = ...): ...
def isclose(x: Any, y: Any, rtol: float = ..., atol: float = ..., equal_nan: bool = ..., name: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

def simple_img_conv_pool(
    input: Any,
    num_filters: Any,
    filter_size: Any,
    pool_size: Any,
    pool_stride: Any,
    pool_padding: int = ...,
    pool_type: str = ...,
    global_pooling: bool = ...,
    conv_stride: int = ...,
    conv_padding: int = ...,
    conv_dilation: int = ...,
    conv_groups: int = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    act: Optional[Any] = ...,
    use_cudnn: bool = ...,
): ...
def img_conv_group(
    input: Any,
    conv_num_filter: Any,
    pool_size: Any,
    conv_padding: int = ...,
    conv_filter_size: int = ...,
    conv_act: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    conv_with_batchnorm: bool = ...,
    conv_batchnorm_drop_rate: float = ...,
    pool_stride: int = ...,
    pool_type: str = ...,
    use_cudnn: bool = ...,
): ...
def sequence_conv_pool(
    input: Any,
    num_filters: Any,
    filter_size: Any,
    param_attr: Optional[Any] = ...,
    act: str = ...,
    pool_type: str = ...,
    bias_attr: Optional[Any] = ...,
): ...
def glu(input: Any, dim: int = ...): ...
def scaled_dot_product_attention(
    queries: Any, keys: Any, values: Any, num_heads: int = ..., dropout_rate: float = ...
): ...



from __future__ import annotations

from typing import Any, Optional

from ...fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ...fluid.framework import in_dygraph_mode as in_dygraph_mode
from ...fluid.layer_helper import LayerHelper as LayerHelper
from ...fluid.layers import dice_loss as dice_loss
from ...fluid.layers import edit_distance as edit_distance
from ...fluid.layers import huber_loss as huber_loss
from ...fluid.layers import log_loss as log_loss
from ...fluid.layers import npair_loss as npair_loss
from ...fluid.layers import square_error_cost as square_error_cost
from ...static import Variable as Variable
from ...tensor.manipulation import reshape as reshape

def binary_cross_entropy(
    input: Any, label: Any, weight: Optional[Any] = ..., reduction: str = ..., name: Optional[Any] = ...
): ...
def binary_cross_entropy_with_logits(
    logit: Any,
    label: Any,
    weight: Optional[Any] = ...,
    reduction: str = ...,
    pos_weight: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def hsigmoid_loss(
    input: Any,
    label: Any,
    num_classes: Any,
    weight: Any,
    bias: Optional[Any] = ...,
    path_table: Optional[Any] = ...,
    path_code: Optional[Any] = ...,
    is_sparse: bool = ...,
    name: Optional[Any] = ...,
): ...
def smooth_l1_loss(input: Any, label: Any, reduction: str = ..., delta: float = ..., name: Optional[Any] = ...): ...
def margin_ranking_loss(
    input: Any, other: Any, label: Any, margin: float = ..., reduction: str = ..., name: Optional[Any] = ...
): ...
def l1_loss(input: Any, label: Any, reduction: str = ..., name: Optional[Any] = ...): ...
def nll_loss(
    input: Any,
    label: Any,
    weight: Optional[Any] = ...,
    ignore_index: int = ...,
    reduction: str = ...,
    name: Optional[Any] = ...,
): ...
def kl_div(input: Any, label: Any, reduction: str = ..., name: Optional[Any] = ...): ...
def mse_loss(input: Any, label: Any, reduction: str = ..., name: Optional[Any] = ...): ...
def ctc_loss(
    log_probs: Any,
    labels: Any,
    input_lengths: Any,
    label_lengths: Any,
    blank: int = ...,
    reduction: str = ...,
    norm_by_times: bool = ...,
): ...
def margin_cross_entropy(
    logits: Any,
    label: Any,
    margin1: float = ...,
    margin2: float = ...,
    margin3: float = ...,
    scale: float = ...,
    group: Optional[Any] = ...,
    return_softmax: bool = ...,
    reduction: str = ...,
): ...
def softmax_with_cross_entropy(
    logits: Any,
    label: Any,
    soft_label: bool = ...,
    ignore_index: int = ...,
    numeric_stable_mode: bool = ...,
    return_softmax: bool = ...,
    axis: int = ...,
): ...
def cross_entropy(
    input: Any,
    label: Any,
    weight: Optional[Any] = ...,
    ignore_index: int = ...,
    reduction: str = ...,
    soft_label: bool = ...,
    axis: int = ...,
    use_softmax: bool = ...,
    name: Optional[Any] = ...,
): ...
def sigmoid_focal_loss(
    logit: Any,
    label: Any,
    normalizer: Optional[Any] = ...,
    alpha: float = ...,
    gamma: float = ...,
    reduction: str = ...,
    name: Optional[Any] = ...,
): ...
def hinge_embedding_loss(
    input: Any, label: Any, margin: float = ..., reduction: str = ..., name: Optional[Any] = ...
): ...



from __future__ import annotations

from . import batch_sampler as batch_sampler
from . import dataloader_iter as dataloader_iter
from . import dataset as dataset
from . import sampler as sampler
from .batch_sampler import *
from .dataloader_iter import *
from .dataset import *
from .sampler import *



from __future__ import annotations

class DeviceWorker:
    def __init__(self) -> None: ...

class Hogwild(DeviceWorker):
    def __init__(self) -> None: ...

class DownpourLite(DeviceWorker):
    def __init__(self) -> None: ...

class DownpourSGD(DeviceWorker):
    def __init__(self) -> None: ...

class DownpourSGDOPT(DeviceWorker):
    def __init__(self) -> None: ...

class Section(DeviceWorker):
    def __init__(self) -> None: ...

class HeterSection(DeviceWorker):
    def __init__(self) -> None: ...

class DeviceWorkerFactory: ...



from __future__ import annotations

from typing import Any, Optional

class AutoMixedPrecisionLists:
    white_list: Any = ...
    black_list: Any = ...
    gray_list: Any = ...
    unsupported_list: Any = ...
    black_varnames: Any = ...
    def __init__(
        self,
        custom_white_list: Optional[Any] = ...,
        custom_black_list: Optional[Any] = ...,
        custom_black_varnames: Optional[Any] = ...,
    ) -> None: ...

CustomOpLists = AutoMixedPrecisionLists



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

age_table: Any
URL: str
MD5: str

class MovieInfo:
    index: Any = ...
    categories: Any = ...
    title: Any = ...
    def __init__(self, index: Any, categories: Any, title: Any) -> None: ...
    def value(self, categories_dict: Any, movie_title_dict: Any): ...

class UserInfo:
    index: Any = ...
    is_male: Any = ...
    age: Any = ...
    job_id: Any = ...
    def __init__(self, index: Any, gender: Any, age: Any, job_id: Any) -> None: ...
    def value(self): ...

class Movielens(Dataset):
    mode: Any = ...
    data_file: Any = ...
    test_ratio: Any = ...
    rand_seed: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        mode: str = ...,
        test_ratio: float = ...,
        rand_seed: int = ...,
        download: bool = ...,
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...



from __future__ import annotations

from typing import Any, Optional

from .dist_attribute import OperatorDistributedAttribute as OperatorDistributedAttribute
from .dist_attribute import TensorDistributedAttribute as TensorDistributedAttribute
from .dist_context import DistributedContext as DistributedContext
from .process_group import ProcessGroup as ProcessGroup
from .process_group import new_process_group as new_process_group

def get_var_with_recursion(var_name: Any, block: Any, program: Any): ...

class AllGatherOpDesc:
    def __init__(self, group: Any) -> None: ...
    @property
    def group(self): ...
    @property
    def desc(self): ...

class SendOpDesc:
    def __init__(self, partition_index: Any, dst: Any) -> None: ...
    @property
    def partition_index(self): ...
    @property
    def dst(self): ...
    @property
    def desc(self): ...

class RecvOpDesc:
    def __init__(self, partition_index: Any, src: Any) -> None: ...
    @property
    def partition_index(self): ...
    @property
    def src(self): ...
    @property
    def desc(self): ...

class SliceOpDesc:
    def __init__(self, starts: Any, ends: Any, axes: Any) -> None: ...
    @property
    def starts(self): ...
    @property
    def ends(self): ...
    @property
    def axes(self): ...
    @property
    def desc(self): ...

class ConcatOpDesc:
    def __init__(self, partition_index_list: Any) -> None: ...
    @property
    def partition_index_list(self): ...
    @property
    def desc(self): ...

class Inserter:
    @staticmethod
    def insert_send_op(block: Any, idx: Any, tensor: Any, dst: Any, op_role: Any) -> None: ...
    @staticmethod
    def insert_recv_op(block: Any, idx: Any, tensor: Any, src: Any, op_role: Any) -> None: ...
    @staticmethod
    def insert_concat_op(block: Any, idx: Any, tensors: Any, axis: Any, op_role: Any): ...
    @staticmethod
    def insert_slice_op(
        block: Any, idx: Any, tensor: Any, starts: Any, ends: Any, axes: Any, new_var_name: Any, op_role: Any
    ): ...
    @staticmethod
    def insert_split_op(block: Any, idx: Any, tensor: Any, num_or_sections: Any, op_role: Any): ...
    @staticmethod
    def insert_fill_constant_op(block: Any, idx: Any, op_role: Any): ...
    @staticmethod
    def insert_allgather_op(block: Any, idx: Any, tensor: Any, ranks: Any, op_role: Any): ...
    @staticmethod
    def concat_partitions_with_op(
        partition_tensor_list: Any, tensor: Any, partition_index: Any, block: Any, idx: Any, op_role: Any
    ) -> None: ...

class Remover:
    @staticmethod
    def remove_no_need_ops(auto_parallel_main_prog: Any, dist_context: Any, rank_id: Any) -> None: ...
    @staticmethod
    def remove_no_need_vars(auto_parallel_main_prog: Any, dist_params_grads: Any) -> None: ...
    @staticmethod
    def remove_no_need_in_main(
        auto_parallel_main_prog: Any, dist_context: Any, rank_id: Any, dist_params_grads: Any
    ) -> None: ...
    @staticmethod
    def remove_no_need_in_startup(auto_parallel_main_prog: Any, auto_parallel_startup_prog: Any) -> None: ...

class Resharder:
    while_block_info: Any = ...
    def __init__(
        self,
        auto_parallel_main_prog: Any,
        auto_parallel_startup_prog: Any,
        rank_id: Any,
        dist_context: Any,
        dist_params_grads: Any,
        batch_size: Optional[Any] = ...,
    ) -> None: ...
    @property
    def auto_parallel_main_prog(self): ...
    @property
    def auto_parallel_startup_prog(self): ...
    @property
    def rank_id(self): ...
    @property
    def dist_context(self): ...
    @property
    def dist_params_grads(self): ...
    @property
    def batch_size(self): ...
    @property
    def has_sent(self): ...
    @property
    def has_recv(self): ...
    @property
    def has_allgather(self): ...
    @staticmethod
    def compute_partition_shape(complete_shape: Any, dims_mapping: Any, process_shape: Any): ...
    @staticmethod
    def compute_process_index(process: Any, process_group: Any, process_shape: Any): ...
    @staticmethod
    def compute_partition_index(
        process: Any, complete_shape: Any, dims_mapping: Any, process_shape: Any, process_group: Any
    ): ...
    @staticmethod
    def compute_concat_info(partition_index_x: Any, partition_index_y: Any): ...
    @staticmethod
    def compute_complete_shape(slice_shape: Any, process_shape: Any, dims_mapping: Any): ...
    @staticmethod
    def concat_partitions(partition_index_list: Any, partition_index: Any) -> None: ...
    @staticmethod
    def change_while_op_input_and_output(auto_parallel_main_prog: Any, dist_context: Any) -> None: ...
    def is_overlapped(self, shape_x: Any, shape_y: Any): ...
    def is_unshard(self, dims_mapping: Any): ...
    def is_special_op(self, op: Any): ...
    def is_condition_replicative(self, op: Any): ...
    def need_reshard(self, dist_tensor: Any, dist_op: Any, actual_process_mesh: Any, op_input: bool = ...): ...
    def get_process_meshes(self, op: Any): ...
    def get_op_process_meshes(self, op: Any): ...
    def get_while_op_actual_process_mesh(self, op: Any): ...
    def find_op_desc_seq(self, dist_tensor: Any, dist_op: Any, actual_process_mesh: Any): ...
    def parse_op_desc(self, block: Any, op_desc_seq: Any, var_name: Any, reshard_op: Any, actual_process_mesh: Any): ...
    def reshard(self) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.dataset.image import batch_images_from_tar as batch_images_from_tar
from paddle.dataset.image import load_image as load_image

from .common import download as download

DATA_URL: str
LABEL_URL: str
SETID_URL: str
DATA_MD5: str
LABEL_MD5: str
SETID_MD5: str
TRAIN_FLAG: str
TEST_FLAG: str
VALID_FLAG: str

def default_mapper(is_train: Any, sample: Any): ...

train_mapper: Any
test_mapper: Any

def reader_creator(
    data_file: Any,
    label_file: Any,
    setid_file: Any,
    dataset_name: Any,
    mapper: Any,
    buffered_size: int = ...,
    use_xmap: bool = ...,
    cycle: bool = ...,
): ...
def train(mapper: Any = ..., buffered_size: int = ..., use_xmap: bool = ..., cycle: bool = ...): ...
def test(mapper: Any = ..., buffered_size: int = ..., use_xmap: bool = ..., cycle: bool = ...): ...
def valid(mapper: Any = ..., buffered_size: int = ..., use_xmap: bool = ...): ...
def fetch() -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

DATA_URL: str
LABEL_URL: str
SETID_URL: str
DATA_MD5: str
LABEL_MD5: str
SETID_MD5: str
MODE_FLAG_MAP: Any

class Flowers(Dataset):
    backend: Any = ...
    transform: Any = ...
    data_path: Any = ...
    labels: Any = ...
    indexes: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        label_file: Optional[Any] = ...,
        setid_file: Optional[Any] = ...,
        mode: str = ...,
        transform: Optional[Any] = ...,
        download: bool = ...,
        backend: Optional[Any] = ...,
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...



from __future__ import annotations

from typing import Any, Optional

class StaticModelRunner:
    def __new__(cls, model_dir: Any, model_filename: Optional[Any] = ..., params_filename: Optional[Any] = ...): ...



from __future__ import annotations

from functools import partial as partial
from functools import reduce as reduce
from typing import Any, Optional

from paddle import framework as framework
from paddle.device import get_cudnn_version as get_cudnn_version
from paddle.device import get_device as get_device
from paddle.fluid.data_feeder import convert_dtype as convert_dtype
from paddle.fluid.layers.utils import flatten as flatten
from paddle.fluid.layers.utils import map_structure as map_structure
from paddle.fluid.layers.utils import pack_sequence_as as pack_sequence_as
from paddle.nn import Layer
from paddle.nn import LayerList as LayerList

def resnet_unit(
    x: Any,
    filter_x: Any,
    scale_x: Any,
    bias_x: Any,
    mean_x: Any,
    var_x: Any,
    z: Any,
    filter_z: Any,
    scale_z: Any,
    bias_z: Any,
    mean_z: Any,
    var_z: Any,
    stride: Any,
    stride_z: Any,
    padding: Any,
    dilation: Any,
    groups: Any,
    momentum: Any,
    eps: Any,
    data_format: Any,
    fuse_add: Any,
    has_shortcut: Any,
    use_global_stats: Any,
    is_test: Any,
    act: Any,
): ...

class ResNetUnit(Layer):
    filter_x: Any = ...
    scale_x: Any = ...
    bias_x: Any = ...
    mean_x: Any = ...
    var_x: Any = ...
    filter_z: Any = ...
    scale_z: Any = ...
    bias_z: Any = ...
    mean_z: Any = ...
    var_z: Any = ...
    def __init__(
        self,
        num_channels_x: Any,
        num_filters: Any,
        filter_size: Any,
        stride: int = ...,
        momentum: float = ...,
        eps: float = ...,
        data_format: str = ...,
        act: str = ...,
        fuse_add: bool = ...,
        has_shortcut: bool = ...,
        use_global_stats: bool = ...,
        is_test: bool = ...,
        filter_x_attr: Optional[Any] = ...,
        scale_x_attr: Optional[Any] = ...,
        bias_x_attr: Optional[Any] = ...,
        moving_mean_x_name: Optional[Any] = ...,
        moving_var_x_name: Optional[Any] = ...,
        num_channels_z: int = ...,
        stride_z: int = ...,
        filter_z_attr: Optional[Any] = ...,
        scale_z_attr: Optional[Any] = ...,
        bias_z_attr: Optional[Any] = ...,
        moving_mean_z_name: Optional[Any] = ...,
        moving_var_z_name: Optional[Any] = ...,
    ): ...
    def forward(self, x: Any, z: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any

class EntryAttr:
    def __init__(self) -> None: ...

class ProbabilityEntry(EntryAttr):
    def __init__(self, probability: Any) -> None: ...

class CountFilterEntry(EntryAttr):
    def __init__(self, count_filter: Any) -> None: ...

class ShowClickEntry(EntryAttr):
    def __init__(self, show_name: Any, click_name: Any) -> None: ...



from __future__ import annotations

from typing import Any

age_table: Any
URL: str
MD5: str

class MovieInfo:
    index: Any = ...
    categories: Any = ...
    title: Any = ...
    def __init__(self, index: Any, categories: Any, title: Any) -> None: ...
    def value(self): ...

class UserInfo:
    index: Any = ...
    is_male: Any = ...
    age: Any = ...
    job_id: Any = ...
    def __init__(self, index: Any, gender: Any, age: Any, job_id: Any) -> None: ...
    def value(self): ...

MOVIE_INFO: Any
MOVIE_TITLE_DICT: Any
CATEGORIES_DICT: Any
USER_INFO: Any

def __initialize_meta_info__(): ...
def __reader__(rand_seed: int = ..., test_ratio: float = ..., is_test: bool = ...) -> None: ...
def __reader_creator__(**kwargs: Any): ...

train: Any
test: Any

def get_movie_title_dict(): ...
def __max_index_info__(a: Any, b: Any): ...
def max_movie_id(): ...
def max_user_id(): ...
def __max_job_id_impl__(a: Any, b: Any): ...
def max_job_id(): ...
def movie_categories(): ...
def user_info(): ...
def movie_info(): ...
def unittest() -> None: ...
def fetch() -> None: ...



from __future__ import annotations

from typing import Any

from paddle.common_ops_import import dygraph_only as dygraph_only

from ..fluid.data_feeder import check_dtype as check_dtype
from ..fluid.data_feeder import check_type as check_type
from ..fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..fluid.framework import in_dygraph_mode as in_dygraph_mode
from ..fluid.layer_helper import LayerHelper as LayerHelper
from .linalg import dot as dot
from .linalg import matmul as matmul
from .linalg import transpose as transpose
from .manipulation import reshape as reshape
from .manipulation import squeeze as squeeze
from .manipulation import unsqueeze as unsqueeze
from .math import multiply as multiply

def parse_op_labels(labelstr: Any, operand: Any): ...
def parse_labels(labelstr: Any, operands: Any): ...
def validate_rhs(rhs: Any, input_labels: Any, n_bcast_dims: Any) -> None: ...
def build_view(in_labels: Any, out_labels: Any): ...
def build_global_view(nop_labels: Any, rhs: Any, n_bcast_dims: Any): ...
def build_global_shape(g_view: Any, g_labels: Any, op_shapes: Any): ...
def has_duplicated_labels(labels: Any): ...
def diagonalize(labels: Any, operand: Any): ...
def plan_reduce(plan: Any, op: Any, reduce_dims: Any, keepdim: Any): ...
def plan_scalar_prod(plan: Any, op1: Any, op2: Any): ...
def plan_matmul(
    plan: Any, g_view: Any, op1: Any, op2: Any, g_supports: Any, g_shape: Any, I: Any, J1: Any, J2: Any, K: Any
) -> None: ...
def plan_summation(
    plan: Any, g_view: Any, op1: Any, op2: Any, g_supports: Any, g_shape: Any, g_count: Any, n_bcast: Any
) -> None: ...
def rearrange(axes: Any): ...
def plan_broadcast(plan: Any, operands: Any, nop_axes: Any): ...

class Plan:
    env: Any = ...
    steps: Any = ...
    def __init__(self) -> None: ...
    def add_step(self, step: Any) -> None: ...
    def get_var(self, varname: Any): ...
    def set_var(self, varname: Any, var: Any) -> None: ...
    def show(self): ...
    def execute(self): ...

def plan_einsum(operands: Any, g_view: Any, g_shape: Any, g_supports: Any, g_count: Any, n_bcast: Any): ...
def preprocess(equation: Any, *operands: Any): ...
def parse_fake_shape(equation: Any, operands: Any, labels: Any): ...
def rhs_inference(lhs: Any): ...
def gen_equation_for_opteinsum(lhs: Any, rhs: Any): ...
def einsum_v2(equation: Any, *operands: Any): ...
def gen_einsum_op(equation: Any, *operands: Any): ...
def einsum(equation: Any, *operands: Any): ...



from __future__ import annotations

from typing import Any, Optional

import paddle

from ..meta_optimizers import HeterParallelOptimizer as HeterParallelOptimizer
from ..meta_optimizers import HybridParallelOptimizer as HybridParallelOptimizer
from ..meta_parallel import PipelineParallel as PipelineParallel
from ..meta_parallel import ShardingParallel as ShardingParallel
from ..meta_parallel import TensorParallel as TensorParallel
from ..meta_parallel import model_parallel_random_seed as model_parallel_random_seed
from .distributed_strategy import DistributedStrategy as DistributedStrategy
from .meta_optimizer_factory import MetaOptimizerFactory as MetaOptimizerFactory
from .role_maker import PaddleCloudRoleMaker as PaddleCloudRoleMaker
from .role_maker import RoleMakerBase as RoleMakerBase
from .role_maker import UserDefinedRoleMaker as UserDefinedRoleMaker
from .runtime_factory import RuntimeFactory as RuntimeFactory
from .strategy_compiler import StrategyCompiler as StrategyCompiler
from .topology import ParallelMode as ParallelMode

class _RecomputeModelWrapper(paddle.nn.Layer):
    def __init__(self, model: Any, segments: int = ..., preserve_rng_state: bool = ...) -> None: ...
    def forward(self, input: Any): ...

def apply_ir_passes(main_program: Any, startup_program: Any, config: Any): ...

inited_runtime_handler: Any
is_non_distributed_check: Any

class Fleet:
    strategy_compiler: Any = ...
    def __init__(self) -> None: ...
    def init(
        self, role_maker: Optional[Any] = ..., is_collective: bool = ..., strategy: Optional[Any] = ...
    ) -> None: ...
    def get_hybrid_communicate_group(self): ...
    def get_hybrid_parallel_topology(self): ...
    def is_first_worker(self): ...
    def worker_index(self): ...
    def worker_num(self): ...
    def node_num(self): ...
    def local_rank(self): ...
    def local_device_ids(self): ...
    def world_device_ids(self): ...
    def is_worker(self): ...
    def worker_endpoints(self, to_string: bool = ...): ...
    def server_num(self): ...
    def server_index(self): ...
    def server_endpoints(self, to_string: bool = ...): ...
    def is_server(self): ...
    def barrier_worker(self) -> None: ...
    def init_worker(self, scopes: Optional[Any] = ...) -> None: ...
    def init_server(self, *args: Any, **kwargs: Any) -> None: ...
    def load_model(self, path: Any, mode: Any) -> None: ...
    def run_server(self) -> None: ...
    def stop_worker(self) -> None: ...
    def save(self, dirname: Any, feed: Any = ..., fetch: Any = ..., **configs: Any) -> None: ...
    def save_inference_model(
        self,
        executor: Any,
        dirname: Any,
        feeded_var_names: Any,
        target_vars: Any,
        main_program: Optional[Any] = ...,
        export_for_deployment: bool = ...,
        mode: int = ...,
    ) -> None: ...
    def save_persistables(
        self, executor: Any, dirname: Any, main_program: Optional[Any] = ..., mode: int = ...
    ) -> None: ...
    def shrink(self, threshold: Optional[Any] = ...) -> None: ...
    user_defined_optimizer: Any = ...
    def distributed_optimizer(self, optimizer: Any, strategy: Optional[Any] = ...): ...
    def distributed_model(self, model: Any): ...
    def state_dict(self): ...
    def set_state_dict(self, state_dict: Any): ...
    def set_lr(self, value: Any): ...
    def get_lr(self): ...
    def step(self): ...
    def clear_grad(self): ...
    def get_loss_scaling(self): ...
    def amp_init(
        self, place: Any, scope: Optional[Any] = ..., test_program: Optional[Any] = ..., use_fp16_test: bool = ...
    ): ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...
    def distributed_scaler(self, scaler: Any): ...



from __future__ import annotations

from typing import Any, Optional

DATA_URL: str
DATA_MD5: str
WORDDICT_URL: str
WORDDICT_MD5: str
VERBDICT_URL: str
VERBDICT_MD5: str
TRGDICT_URL: str
TRGDICT_MD5: str
EMB_URL: str
EMB_MD5: str
UNK_IDX: int

def load_label_dict(filename: Any): ...
def load_dict(filename: Any): ...
def corpus_reader(data_path: Any, words_name: Any, props_name: Any): ...
def reader_creator(
    corpus_reader: Any,
    word_dict: Optional[Any] = ...,
    predicate_dict: Optional[Any] = ...,
    label_dict: Optional[Any] = ...,
): ...
def get_dict(): ...
def get_embedding(): ...
def test(): ...
def fetch() -> None: ...



from __future__ import annotations

import unittest
from typing import Any

import paddle.fluid as fluid
from paddle.fluid.dygraph import nn as nn
from paddle.fluid.dygraph.io import INFER_MODEL_SUFFIX as INFER_MODEL_SUFFIX
from paddle.fluid.dygraph.io import INFER_PARAMS_SUFFIX as INFER_PARAMS_SUFFIX
from paddle.fluid.framework import IrGraph as IrGraph

def get_vaild_warning_num(warning: Any, w: Any): ...

class ImperativeLenet(fluid.dygraph.Layer):
    features: Any = ...
    fc: Any = ...
    def __init__(self, num_classes: int = ...) -> None: ...
    def forward(self, inputs: Any): ...

class TestImperativeOutSclae(unittest.TestCase):
    root_path: Any = ...
    param_save_path: Any = ...
    save_path: Any = ...
    def setUp(self) -> None: ...
    def tearDown(self) -> None: ...
    def func_out_scale_acc(self) -> None: ...
    def test_out_scale_acc(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

class LRScheduler:
    base_lr: Any = ...
    last_lr: Any = ...
    last_epoch: Any = ...
    verbose: Any = ...
    def __init__(self, learning_rate: float = ..., last_epoch: int = ..., verbose: bool = ...) -> None: ...
    def __call__(self): ...
    def step(self, epoch: Optional[Any] = ...) -> None: ...
    def state_dict(self): ...
    keys: Any = ...
    def state_keys(self) -> None: ...
    def set_state_dict(self, state_dict: Any) -> None: ...
    set_dict: Any = ...
    def get_lr(self) -> None: ...

class NoamDecay(LRScheduler):
    d_model: Any = ...
    warmup_steps: Any = ...
    def __init__(
        self, d_model: Any, warmup_steps: Any, learning_rate: float = ..., last_epoch: int = ..., verbose: bool = ...
    ) -> None: ...
    def get_lr(self): ...

class PiecewiseDecay(LRScheduler):
    boundaries: Any = ...
    values: Any = ...
    def __init__(self, boundaries: Any, values: Any, last_epoch: int = ..., verbose: bool = ...) -> None: ...
    def get_lr(self): ...

class NaturalExpDecay(LRScheduler):
    gamma: Any = ...
    def __init__(self, learning_rate: Any, gamma: Any, last_epoch: int = ..., verbose: bool = ...) -> None: ...
    def get_lr(self): ...

class InverseTimeDecay(LRScheduler):
    gamma: Any = ...
    def __init__(self, learning_rate: Any, gamma: Any, last_epoch: int = ..., verbose: bool = ...) -> None: ...
    def get_lr(self): ...

class PolynomialDecay(LRScheduler):
    decay_steps: Any = ...
    end_lr: Any = ...
    power: Any = ...
    cycle: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        decay_steps: Any,
        end_lr: float = ...,
        power: float = ...,
        cycle: bool = ...,
        last_epoch: int = ...,
        verbose: bool = ...,
    ) -> None: ...
    def get_lr(self): ...

class LinearWarmup(LRScheduler):
    learning_rate: Any = ...
    warmup_steps: Any = ...
    start_lr: Any = ...
    end_lr: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        warmup_steps: Any,
        start_lr: Any,
        end_lr: Any,
        last_epoch: int = ...,
        verbose: bool = ...,
    ) -> None: ...
    def state_dict(self): ...
    def set_state_dict(self, state_dict: Any) -> None: ...
    def get_lr(self): ...

class ExponentialDecay(LRScheduler):
    gamma: Any = ...
    def __init__(self, learning_rate: Any, gamma: Any, last_epoch: int = ..., verbose: bool = ...) -> None: ...
    def get_lr(self): ...

class MultiStepDecay(LRScheduler):
    milestones: Any = ...
    gamma: Any = ...
    def __init__(
        self, learning_rate: Any, milestones: Any, gamma: float = ..., last_epoch: int = ..., verbose: bool = ...
    ) -> None: ...
    def get_lr(self): ...

class StepDecay(LRScheduler):
    step_size: Any = ...
    gamma: Any = ...
    def __init__(
        self, learning_rate: Any, step_size: Any, gamma: float = ..., last_epoch: int = ..., verbose: bool = ...
    ) -> None: ...
    def get_lr(self): ...

class LambdaDecay(LRScheduler):
    lr_lambda: Any = ...
    def __init__(self, learning_rate: Any, lr_lambda: Any, last_epoch: int = ..., verbose: bool = ...) -> None: ...
    def get_lr(self): ...

class ReduceOnPlateau(LRScheduler):
    mode: Any = ...
    factor: Any = ...
    threshold_mode: Any = ...
    patience: Any = ...
    threshold: Any = ...
    cooldown: Any = ...
    min_lr: Any = ...
    epsilon: Any = ...
    cooldown_counter: int = ...
    best: Any = ...
    num_bad_epochs: int = ...
    base_lr: Any = ...
    last_lr: Any = ...
    last_epoch: int = ...
    verbose: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        mode: str = ...,
        factor: float = ...,
        patience: int = ...,
        threshold: float = ...,
        threshold_mode: str = ...,
        cooldown: int = ...,
        min_lr: int = ...,
        epsilon: float = ...,
        verbose: bool = ...,
    ) -> None: ...
    keys: Any = ...
    def state_keys(self) -> None: ...
    def step(self, metrics: Any, epoch: Optional[Any] = ...) -> None: ...

class CosineAnnealingDecay(LRScheduler):
    T_max: Any = ...
    eta_min: Any = ...
    def __init__(
        self, learning_rate: Any, T_max: Any, eta_min: int = ..., last_epoch: int = ..., verbose: bool = ...
    ) -> None: ...
    def get_lr(self): ...

class MultiplicativeDecay(LRScheduler):
    lr_lambda: Any = ...
    def __init__(self, learning_rate: Any, lr_lambda: Any, last_epoch: int = ..., verbose: bool = ...) -> None: ...
    def get_lr(self): ...



from __future__ import annotations

from . import control_flow as control_flow
from . import detection as detection
from . import device as device
from . import io as io
from . import loss as loss
from . import math_op_patch as math_op_patch
from . import metric_op as metric_op
from . import nn as nn
from . import ops as ops
from . import rnn as rnn
from . import tensor as tensor
from .collective import *
from .control_flow import *
from .detection import *
from .device import *
from .distributions import *
from .io import *
from .learning_rate_scheduler import *
from .loss import *
from .math_op_patch import *
from .metric_op import *
from .nn import *
from .ops import *
from .rnn import *
from .sequence_lod import *
from .tensor import *



from __future__ import annotations

from typing import Any

from paddle.utils import gast

class ListTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    list_name_to_updated: Any = ...
    list_nodes: Any = ...
    static_analysis_visitor: Any = ...
    node_to_wrapper_map: Any = ...
    scope_var_type_dict: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_Call(self, node: Any): ...
    def visit_Assign(self, node: Any): ...
    def visit_If(self, node: Any): ...
    def visit_While(self, node: Any): ...
    def visit_For(self, node: Any): ...
    def replace_list_with_tensor_array(self, node: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def Print(
    input: Any,
    first_n: int = ...,
    message: Optional[Any] = ...,
    summarize: int = ...,
    print_tensor_name: bool = ...,
    print_tensor_type: bool = ...,
    print_tensor_shape: bool = ...,
    print_tensor_layout: bool = ...,
    print_tensor_lod: bool = ...,
    print_phase: str = ...,
): ...
def Assert(cond: Any, data: Optional[Any] = ..., summarize: int = ..., name: Optional[Any] = ...): ...

class BlockGuard:
    main_program: Any = ...
    def __init__(self, main_program: Any) -> None: ...
    def __enter__(self) -> None: ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any): ...

class BlockGuardWithCompletion(BlockGuard):
    rnn: Any = ...
    def __init__(self, rnn: Any) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any): ...

class StaticRNNMemoryLink:
    init: Any = ...
    pre_mem: Any = ...
    mem: Any = ...
    def __init__(self, init: Any, pre_mem: Any, mem: Optional[Any] = ...) -> None: ...

class StaticRNN:
    BEFORE_RNN_BLOCK: int = ...
    IN_RNN_BLOCK: int = ...
    AFTER_RNN_BLOCK: int = ...
    helper: Any = ...
    memories: Any = ...
    inputs: Any = ...
    outputs: Any = ...
    status: Any = ...
    seq_len: Any = ...
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def step(self): ...
    def memory(
        self,
        init: Optional[Any] = ...,
        shape: Optional[Any] = ...,
        batch_ref: Optional[Any] = ...,
        init_value: float = ...,
        init_batch_dim_idx: int = ...,
        ref_batch_dim_idx: int = ...,
    ): ...
    def step_input(self, x: Any): ...
    def step_output(self, o: Any) -> None: ...
    def output(self, *outputs: Any) -> None: ...
    def update_memory(self, mem: Any, var: Any) -> None: ...
    def __call__(self, *args: Any, **kwargs: Any): ...

class WhileGuard(BlockGuard):
    while_op: Any = ...
    def __init__(self, while_op: Any) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any): ...

class While:
    BEFORE_WHILE_BLOCK: int = ...
    IN_WHILE_BLOCK: int = ...
    AFTER_WHILE_BLOCK: int = ...
    helper: Any = ...
    status: Any = ...
    cond_var: Any = ...
    is_test: Any = ...
    def __init__(self, cond: Any, is_test: bool = ..., name: Optional[Any] = ...): ...
    def block(self): ...

def while_loop(cond: Any, body: Any, loop_vars: Any, is_test: bool = ..., name: Optional[Any] = ...): ...
def increment(x: Any, value: float = ..., in_place: bool = ...): ...
def array_write(x: Any, i: Any, array: Optional[Any] = ...): ...
def create_array(dtype: Any, initialized_list: Optional[Any] = ...): ...
def less_than(x: Any, y: Any, force_cpu: Optional[Any] = ..., cond: Optional[Any] = ..., name: Optional[Any] = ...): ...
def less_equal(x: Any, y: Any, cond: Optional[Any] = ..., name: Optional[Any] = ...): ...
def greater_than(x: Any, y: Any, cond: Optional[Any] = ..., name: Optional[Any] = ...): ...
def greater_equal(x: Any, y: Any, cond: Optional[Any] = ..., name: Optional[Any] = ...): ...
def equal(x: Any, y: Any, cond: Optional[Any] = ..., name: Optional[Any] = ...): ...
def not_equal(x: Any, y: Any, cond: Optional[Any] = ..., name: Optional[Any] = ...): ...
def array_read(array: Any, i: Any): ...
def array_length(array: Any): ...

class ConditionalBlockGuard(BlockGuard):
    block: Any = ...
    def __init__(self, block: Any) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any): ...

class ConditionalBlock:
    inputs: Any = ...
    is_scalar_condition: Any = ...
    helper: Any = ...
    def __init__(self, inputs: Any, is_scalar_condition: bool = ..., name: Optional[Any] = ...) -> None: ...
    def block(self): ...
    def complete(self) -> None: ...
    def need_append_conditional_block_grad(self, inside_block: Any): ...
    def append_conditional_block_grad(
        self, parent_block: Any, inside_block: Any, conditional_block_op: Any
    ) -> None: ...

def cond(pred: Any, true_fn: Optional[Any] = ..., false_fn: Optional[Any] = ..., name: Optional[Any] = ...): ...
def case(pred_fn_pairs: Any, default: Optional[Any] = ..., name: Optional[Any] = ...): ...

class Switch:
    helper: Any = ...
    inside_scope: bool = ...
    pre_not_conditions: Any = ...
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def case(self, condition: Any): ...
    def default(self): ...
    def __enter__(self): ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any): ...

class IfElseBlockGuard:
    is_true: Any = ...
    ie: Any = ...
    cond_block: Any = ...
    def __init__(self, is_true: Any, ifelse: Any) -> None: ...
    def __enter__(self) -> None: ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any): ...

class IfElse:
    OUT_IF_ELSE_BLOCKS: int = ...
    IN_IF_ELSE_TRUE_BLOCKS: int = ...
    IN_IF_ELSE_FALSE_BLOCKS: int = ...
    helper: Any = ...
    cond: Any = ...
    input_table: Any = ...
    status: Any = ...
    conditional_true_block: Any = ...
    conditional_false_block: Any = ...
    output_table: Any = ...
    def __init__(self, cond: Any, name: Optional[Any] = ...) -> None: ...
    def input(self, x: Any): ...
    def true_block(self): ...
    def false_block(self): ...
    def output(self, *outs: Any) -> None: ...
    def __call__(self): ...

class DynamicRNN:
    BEFORE_RNN: int = ...
    IN_RNN: int = ...
    AFTER_RNN: int = ...
    helper: Any = ...
    status: Any = ...
    lod_rank_table: Any = ...
    max_seq_len: Any = ...
    step_idx: Any = ...
    zero_idx: Any = ...
    mem_dict: Any = ...
    output_array: Any = ...
    outputs: Any = ...
    cond: Any = ...
    while_op: Any = ...
    input_array: Any = ...
    mem_link: Any = ...
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def step_input(self, x: Any, level: int = ...): ...
    def static_input(self, x: Any): ...
    def block(self) -> None: ...
    def __call__(self, *args: Any, **kwargs: Any): ...
    def memory(
        self,
        init: Optional[Any] = ...,
        shape: Optional[Any] = ...,
        value: float = ...,
        need_reorder: bool = ...,
        dtype: str = ...,
    ): ...
    def update_memory(self, ex_mem: Any, new_mem: Any) -> None: ...
    def output(self, *outputs: Any) -> None: ...

def switch_case(branch_index: Any, branch_fns: Any, default: Optional[Any] = ..., name: Optional[Any] = ...): ...
def reorder_lod_tensor_by_rank(x: Any, rank_table: Any): ...
def is_empty(x: Any, name: Optional[Any] = ...): ...



from __future__ import annotations

from .. import core as core
from .. import framework as framework
from ..framework import Variable as Variable
from ..framework import convert_np_dtype_to_dtype_ as convert_np_dtype_to_dtype_
from ..framework import in_dygraph_mode as in_dygraph_mode
from ..layers.layer_function_generator import OpProtoHolder as OpProtoHolder
from . import no_grad as no_grad

def monkey_patch_math_varbase(): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid import dygraph_utils as dygraph_utils

def fused_feedforward(
    x: Any,
    linear1_weight: Any,
    linear2_weight: Any,
    linear1_bias: Optional[Any] = ...,
    linear2_bias: Optional[Any] = ...,
    ln1_scale: Optional[Any] = ...,
    ln1_bias: Optional[Any] = ...,
    ln2_scale: Optional[Any] = ...,
    ln2_bias: Optional[Any] = ...,
    dropout1_rate: float = ...,
    dropout2_rate: float = ...,
    activation: str = ...,
    ln1_epsilon: float = ...,
    ln2_epsilon: float = ...,
    pre_layer_norm: bool = ...,
    training: bool = ...,
    mode: str = ...,
    ring_id: int = ...,
    add_residual: bool = ...,
    name: Optional[Any] = ...,
): ...
def fused_multi_head_attention(
    x: Any,
    qkv_weight: Any,
    linear_weight: Any,
    pre_layer_norm: bool = ...,
    pre_ln_scale: Optional[Any] = ...,
    pre_ln_bias: Optional[Any] = ...,
    ln_scale: Optional[Any] = ...,
    ln_bias: Optional[Any] = ...,
    pre_ln_epsilon: float = ...,
    qkv_bias: Optional[Any] = ...,
    linear_bias: Optional[Any] = ...,
    cache_kv: Optional[Any] = ...,
    attn_mask: Optional[Any] = ...,
    dropout_rate: float = ...,
    attn_dropout_rate: float = ...,
    ln_epsilon: float = ...,
    training: bool = ...,
    mode: str = ...,
    ring_id: int = ...,
    add_residual: bool = ...,
    name: Optional[Any] = ...,
): ...
def fused_multi_transformer(
    x: Any,
    ln_scales: Any,
    ln_biases: Any,
    qkv_weights: Any,
    qkv_biases: Any,
    linear_weights: Any,
    linear_biases: Any,
    ffn_ln_scales: Any,
    ffn_ln_biases: Any,
    ffn1_weights: Any,
    ffn1_biases: Any,
    ffn2_weights: Any,
    ffn2_biases: Any,
    pre_layer_norm: bool = ...,
    epsilon: float = ...,
    cache_kvs: Optional[Any] = ...,
    time_step: Optional[Any] = ...,
    attn_mask: Optional[Any] = ...,
    dropout_rate: float = ...,
    activation: str = ...,
    training: bool = ...,
    mode: str = ...,
    ring_id: int = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

class PSMode:
    TRANSPILER: int = ...
    PSLIB: int = ...

class DistributedMode:
    SYNC: int = ...
    ASYNC: int = ...
    HALF_ASYNC: int = ...
    GEO: int = ...



from __future__ import annotations

from typing import Any

def get_cloud_cluster(args_node_ips: Any, args_node_ip: Any, args_port: Any, selected_devices: Any): ...
def get_cluster_and_pod(args: Any): ...



from __future__ import annotations

from typing import Any

from paddle.distributed.fleet import ascend_utils as ascend_utils
from paddle.distributed.fleet import cloud_utils as cloud_utils
from paddle.distributed.fleet import launch_utils as launch_utils
from paddle.distributed.fleet.elastic.manager import LauncherInterface
from paddle.distributed.fleet.launch_utils import *

class CollectiveLauncher(LauncherInterface):
    args: Any = ...
    procs: Any = ...
    def __init__(self, args: Any) -> None: ...
    tmp_dir: Any = ...
    def launch(self) -> None: ...
    def stop(self) -> None: ...
    def watch(self): ...



from __future__ import annotations

from typing import Any, Optional

class UniqueNameGenerator:
    ids: Any = ...
    prefix: Any = ...
    def __init__(self, prefix: Optional[Any] = ...) -> None: ...
    def __call__(self, key: Any): ...

class DygraphParameterNameChecker:
    def __init__(self) -> None: ...
    def __call__(self, name: Any): ...

def generate(key: Any): ...
def switch(new_generator: Optional[Any] = ..., new_para_name_checker: Optional[Any] = ...): ...
def guard(new_generator: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def fused_elemwise_activation(
    x: Any, y: Any, functor_list: Any, axis: int = ..., scale: float = ..., save_intermediate_out: bool = ...
): ...
def var_conv_2d(
    input: Any,
    row: Any,
    col: Any,
    input_channel: Any,
    output_channel: Any,
    filter_size: Any,
    stride: int = ...,
    param_attr: Optional[Any] = ...,
    act: Optional[Any] = ...,
    dtype: str = ...,
    name: Optional[Any] = ...,
): ...
def match_matrix_tensor(
    x: Any,
    y: Any,
    channel_num: Any,
    act: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    dtype: str = ...,
    name: Optional[Any] = ...,
): ...
def sequence_topk_avg_pooling(input: Any, row: Any, col: Any, topks: Any, channel_num: Any): ...
def tree_conv(
    nodes_vector: Any,
    edge_set: Any,
    output_size: Any,
    num_filters: int = ...,
    max_depth: int = ...,
    act: str = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def fused_embedding_seq_pool(
    input: Any,
    size: Any,
    is_sparse: bool = ...,
    padding_idx: Optional[Any] = ...,
    combiner: str = ...,
    param_attr: Optional[Any] = ...,
    dtype: str = ...,
): ...
def fused_seqpool_cvm(
    input: Any, pool_type: Any, cvm: Any, pad_value: float = ..., use_cvm: bool = ..., cvm_offset: int = ...
): ...
def multiclass_nms2(
    bboxes: Any,
    scores: Any,
    score_threshold: Any,
    nms_top_k: Any,
    keep_top_k: Any,
    nms_threshold: float = ...,
    normalized: bool = ...,
    nms_eta: float = ...,
    background_label: int = ...,
    return_index: bool = ...,
    name: Optional[Any] = ...,
): ...
def search_pyramid_hash(
    input: Any,
    num_emb: Any,
    space_len: Any,
    pyramid_layer: Any,
    rand_len: Any,
    drop_out_percent: Any,
    is_training: Any,
    use_filter: Any,
    white_list_len: Any,
    black_list_len: Any,
    seed: Any,
    lr: Any,
    param_attr: Optional[Any] = ...,
    param_attr_wl: Optional[Any] = ...,
    param_attr_bl: Optional[Any] = ...,
    name: Optional[Any] = ...,
    distribute_update_vars: Optional[Any] = ...,
    dtype: str = ...,
): ...
def shuffle_batch(x: Any, seed: Optional[Any] = ...): ...
def partial_concat(input: Any, start_index: int = ..., length: int = ...): ...
def partial_sum(input: Any, start_index: int = ..., length: int = ...): ...
def sparse_embedding(
    input: Any,
    size: Any,
    padding_idx: Optional[Any] = ...,
    is_test: bool = ...,
    entry: Optional[Any] = ...,
    table_class: str = ...,
    param_attr: Optional[Any] = ...,
    dtype: str = ...,
): ...
def tdm_child(x: Any, node_nums: Any, child_nums: Any, param_attr: Optional[Any] = ..., dtype: str = ...): ...
def tdm_sampler(
    x: Any,
    neg_samples_num_list: Any,
    layer_node_num_list: Any,
    leaf_node_num: Any,
    tree_travel_attr: Optional[Any] = ...,
    tree_layer_attr: Optional[Any] = ...,
    output_positive: bool = ...,
    output_list: bool = ...,
    seed: int = ...,
    tree_dtype: str = ...,
    dtype: str = ...,
): ...
def rank_attention(
    input: Any, rank_offset: Any, rank_param_shape: Any, rank_param_attr: Any, max_rank: int = ..., max_size: int = ...
): ...
def batch_fc(
    input: Any, param_size: Any, param_attr: Any, bias_size: Any, bias_attr: Any, act: Optional[Any] = ...
): ...
def bilateral_slice(x: Any, guide: Any, grid: Any, has_offset: Any, name: Optional[Any] = ...): ...
def correlation(
    x: Any,
    y: Any,
    pad_size: Any,
    kernel_size: Any,
    max_displacement: Any,
    stride1: Any,
    stride2: Any,
    corr_type_multiply: int = ...,
): ...
def fused_bn_add_act(
    x: Any,
    y: Any,
    momentum: float = ...,
    epsilon: float = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    moving_mean_name: Optional[Any] = ...,
    moving_variance_name: Optional[Any] = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...

# Names in __all__ with no definition:
#   _pull_box_extended_sparse



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.dygraph.layers import Layer

from ...utils.log_util import layer_to_str as layer_to_str
from ...utils.log_util import logger as logger

class LayerDesc:
    layer_func: Any = ...
    inputs: Any = ...
    kwargs: Any = ...
    def __init__(self, layer_func: Any, *inputs: Any, **kwargs: Any) -> None: ...
    def build_layer(self): ...

class SharedLayerDesc(LayerDesc):
    layer_name: Any = ...
    forward_func: Any = ...
    shared_weight_attr: Any = ...
    def __init__(
        self,
        key: Any,
        layer_func: Any,
        forward_func: Optional[Any] = ...,
        shared_weight_attr: str = ...,
        *inputs: Any,
        **kwargs: Any,
    ) -> None: ...

class SegmentLayers:
    method: Any = ...
    num_parts: Any = ...
    num_items: Any = ...
    def __init__(self, layers_desc: Any, num_parts: Any, method: str = ...) -> None: ...
    def do_segment(self): ...
    def uniform(self, num_items: Any, num_parts: Any): ...

class PipelineLayer(Layer):
    device_id: Any = ...
    layers: Any = ...
    global_rank: Any = ...
    shared_layers: Any = ...
    shared_weight_attrs: Any = ...
    run_function: Any = ...
    shared_comm: Any = ...
    def __init__(
        self,
        layers: Any,
        num_stages: Optional[Any] = ...,
        topology: Optional[Any] = ...,
        loss_fn: Optional[Any] = ...,
        seg_method: str = ...,
        recompute_interval: int = ...,
        recompute_offload: bool = ...,
        recompute_partition: bool = ...,
    ) -> None: ...
    def get_stage_from_index(self, layer_idx: Any): ...
    def allreduce_shared_weight_gradients(self) -> None: ...
    def forward_function(self, start: Any, end: Any): ...
    def forward(self, input: Any): ...
    def save_state_dict(self, path: Any): ...
    def set_state_dir(self, path: Any) -> None: ...



from __future__ import annotations

from .._typing import bfloat16 as bfloat16
from .._typing import bool as bool
from .._typing import complex64 as complex64
from .._typing import complex128 as complex128
from .._typing import dtype as dtype
from .._typing import float16 as float16
from .._typing import float32 as float32
from .._typing import float64 as float64
from .._typing import int8 as int8
from .._typing import int16 as int16
from .._typing import int32 as int32
from .._typing import int64 as int64
from .._typing import uint8 as uint8



from __future__ import annotations

from typing import Any

def kl_divergence(p: Any, q: Any): ...
def register_kl(cls_p: Any, cls_q: Any): ...

class _Compare:
    classes: Any = ...
    def __init__(self, *classes: Any) -> None: ...
    def __eq__(self, other: Any) -> Any: ...
    def __le__(self, other: Any) -> Any: ...



from __future__ import annotations

from typing import Any, Optional

class ParallelExecutor:
    def __init__(
        self,
        use_cuda: Any,
        loss_name: Optional[Any] = ...,
        main_program: Optional[Any] = ...,
        share_vars_from: Optional[Any] = ...,
        exec_strategy: Optional[Any] = ...,
        build_strategy: Optional[Any] = ...,
        num_trainers: int = ...,
        trainer_id: int = ...,
        scope: Optional[Any] = ...,
    ) -> None: ...
    def run(
        self, fetch_list: Any, feed: Optional[Any] = ..., feed_dict: Optional[Any] = ..., return_numpy: bool = ...
    ): ...
    @property
    def device_count(self): ...
    def drop_local_exe_scopes(self) -> None: ...



from __future__ import annotations

from .dataset import BoxPSDataset as BoxPSDataset
from .dataset import DatasetBase as DatasetBase
from .dataset import FileInstantDataset as FileInstantDataset
from .dataset import InMemoryDataset as InMemoryDataset
from .dataset import QueueDataset as QueueDataset
from .index_dataset import TreeIndex as TreeIndex



from __future__ import annotations

from typing import Any

from paddle.fluid.data_feeder import convert_dtype as convert_dtype

def set_default_dtype(d: Any) -> None: ...
def get_default_dtype(): ...
def set_grad_enabled(mode: Any) -> None: ...
def is_grad_enabled(): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.nn import Layer
from typing_extensions import Literal

from ..._typing import Tensor
from ...framework import ParamAttr

class CELU(Layer):
    def __init__(self, alpha: float = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class ELU(Layer):
    def __init__(self, alpha: float = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class GELU(Layer):
    def __init__(self, approximate: bool = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Hardshrink(Layer):
    def __init__(self, threshold: float = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Hardswish(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Tanh(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Hardtanh(Layer):
    def __init__(self, min: float = ..., max: float = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class PReLU(Layer):
    def __init__(
        self,
        num_parameters: int = ...,
        init: float = ...,
        weight_attr: Optional[ParamAttr] = ...,
        data_format: Literal["NC", "NCL", "NCHW", "NCDHW", "NLC", "NHWC", "NDHWC"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class ReLU(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class ReLU6(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class SELU(Layer):
    def __init__(self, scale: float = ..., alpha: float = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class LeakyReLU(Layer):
    def __init__(self, negative_slope: float = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Sigmoid(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Hardsigmoid(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Softplus(Layer):
    def __init__(self, beta: int = ..., threshold: int = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Softshrink(Layer):
    def __init__(self, threshold: float = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Softsign(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Swish(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Mish(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Tanhshrink(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class ThresholdedReLU(Layer):
    def __init__(self, threshold: float = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Silu(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class LogSigmoid(Layer):
    def __init__(self, name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Softmax(Layer):
    def __init__(self, axis: int = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class LogSoftmax(Layer):
    def __init__(self, axis: int = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward

class Maxout(Layer):
    def __init__(self, groups: Any, axis: int = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> str: ...
    __call__ = forward



from __future__ import annotations

from typing import Any

class WeightDecayRegularizer:
    def __init__(self) -> None: ...
    def __call__(self, param: Any, grad: Any, block: Any) -> None: ...

class L2DecayRegularizer(WeightDecayRegularizer):
    def __init__(self, regularization_coeff: float = ...) -> None: ...
    def __call__(self, param: Any, grad: Any, block: Any): ...

class L1DecayRegularizer(WeightDecayRegularizer):
    def __init__(self, regularization_coeff: float = ...) -> None: ...
    def __call__(self, param: Any, grad: Any, block: Any): ...

L1Decay = L1DecayRegularizer
L2Decay = L2DecayRegularizer



from __future__ import annotations

from typing import Any

layer_name_map: Any
fake_quant_input_layers: Any
fake_quant_output_layers: Any
fake_quant_leaf_layers: Any
fake_quant_wrap_layers: Any
spec_channel_axis_layers: Any
weight_op_types: Any
fake_quantize_dequantize_op_types: Any

def load_variable_data(scope: Any, var_name: Any): ...
def find_previous_op(block: Any, var_name: Any): ...
def find_next_ops(block: Any, var_name: Any): ...
def find_parent_layer_and_sub_name(model: Any, name: Any): ...
def program_all_ops(program: Any): ...
def is_leaf_layer(layer: Any): ...
def fp_numpy_to_naive(x_np: Any): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.distributed.fleet import cloud_utils as cloud_utils

from .cluster import Cluster as Cluster
from .completion import Completer as Completer
from .dist_context import DistributedContext as DistributedContext
from .dist_context import (
    get_default_distributed_context as get_default_distributed_context,
)
from .dist_context import (
    set_default_distributed_context as set_default_distributed_context,
)
from .dist_op import DistributedOperator as DistributedOperator
from .dist_tensor import DistributedTensor as DistributedTensor
from .mapper import mapping as mapping
from .partitioner import Partitioner as Partitioner
from .planner import Planner as Planner
from .process_group import ProcessGroup as ProcessGroup
from .process_group import get_all_process_groups as get_all_process_groups
from .process_group import get_process_group as get_process_group
from .process_group import get_world_process_group as get_world_process_group
from .reshard import Resharder as Resharder
from .utils import SerialProgramInfo as SerialProgramInfo
from .utils import make_data_unshard as make_data_unshard
from .utils import print_program_with_dist_attr as print_program_with_dist_attr
from .utils import set_grad_var_shape as set_grad_var_shape

class AutoParallelizer:
    def __init__(self, fleet: Any) -> None: ...
    def parallelize(
        self,
        loss: Any,
        startup_program: Any,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ): ...
    def __deepcopy__(self, memo: Any): ...



from __future__ import annotations

from typing import Any, Optional

def convert_float_to_uint16(in_list: Any): ...
def bf16_guard() -> None: ...
def cast_model_to_bf16(
    program: Any, startup_prog: Optional[Any] = ..., amp_lists: Optional[Any] = ..., use_bf16_guard: bool = ...
): ...
def cast_parameters_to_bf16(
    place: Any, program: Any, scope: Optional[Any] = ..., to_bf16_var_names: Optional[Any] = ...
) -> None: ...
def rewrite_program_bf16(main_prog: Any, amp_lists: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any

from ....framework import IrNode as IrNode
from ....framework import Operator as Operator

def load_variable_data(scope: Any, var_name: Any): ...
def set_variable_data(scope: Any, place: Any, var_name: Any, np_value: Any) -> None: ...
def quant_tensor(x: Any, scale: Any, quant_axis: int = ..., weight_bits: int = ...): ...
def dequant_tensor(x: Any, scale: Any, quant_axis: int = ..., weight_bits: int = ...): ...
def bias_correction_w(x: Any, x_quant: Any, scale_v: Any, quant_axis: Any, weight_bits: int = ...): ...
def stable_sigmoid(x: Any): ...
def calculate_quant_cos_error(orig_tensor: Any, qdq_tensor: Any): ...

class tqdm:
    total: Any = ...
    bar_format: Any = ...
    ncols: Any = ...
    n: int = ...
    def __init__(self, total: Any, bar_format: str = ..., ncols: int = ...) -> None: ...
    def update(self, n: int = ...) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ...utils.log_util import logger as logger
from .utils import number_2_dtype as number_2_dtype
from .utils import paddle_2_number as paddle_2_number

def initialize_p2p_groups(hcg: Any, use_cache: bool = ...) -> None: ...

class SendRecvMeta:
    send_shape_message: Any = ...
    send_dtype_message: Any = ...
    recv_shape_message: Any = ...
    recv_dtype_message: Any = ...
    recv_stop_gradient: Any = ...
    has_send_meta: bool = ...
    has_recv_meta: bool = ...
    def __init__(self) -> None: ...
    def recv_meta(self, group: Any) -> None: ...
    def send_meta(self, tensor: Any, group: Any) -> None: ...
    def set_send_message(self, tensor: Any) -> None: ...

def send_partial(
    tensor: Any,
    dst: int = ...,
    nranks: int = ...,
    rank_id: int = ...,
    group: Optional[Any] = ...,
    use_calc_stream: bool = ...,
): ...
def recv_partial(
    tensor: Any,
    src: int = ...,
    nranks: int = ...,
    rank_id: int = ...,
    group: Optional[Any] = ...,
    use_calc_stream: bool = ...,
) -> None: ...
def allgather_partial(
    tensor: Any, nranks: int = ..., rank_id: int = ..., group: Optional[Any] = ..., use_calc_stream: bool = ...
): ...
def recv_forward(): ...
def recv_backward(): ...
def send_forward(output_tensor: Any) -> None: ...
def send_backward(input_tensor_grad: Any) -> None: ...
def send_forward_recv_backward(output_tensor: Any): ...
def send_backward_recv_forward(input_tensor_grad: Any): ...



from __future__ import annotations

from .cifar import Cifar10 as Cifar10
from .cifar import Cifar100 as Cifar100
from .flowers import Flowers as Flowers
from .folder import DatasetFolder as DatasetFolder
from .folder import ImageFolder as ImageFolder
from .mnist import MNIST as MNIST
from .mnist import FashionMNIST as FashionMNIST
from .voc2012 import VOC2012 as VOC2012



from __future__ import annotations

from typing import Any, Optional

from .sampler import Sampler

class BatchSampler(Sampler):
    sampler: Any = ...
    batch_size: Any = ...
    drop_last: Any = ...
    def __init__(
        self,
        dataset: Optional[Any] = ...,
        sampler: Optional[Any] = ...,
        shuffle: bool = ...,
        batch_size: int = ...,
        drop_last: bool = ...,
    ) -> None: ...
    def __iter__(self) -> Any: ...
    def __len__(self): ...

class _InfiniteIterableSampler:
    dataset: Any = ...
    batch_size: Any = ...
    def __init__(self, dataset: Any, batch_size: int = ...) -> None: ...
    def __iter__(self) -> Any: ...

class DistributedBatchSampler(BatchSampler):
    dataset: Any = ...
    batch_size: Any = ...
    shuffle: Any = ...
    nranks: Any = ...
    local_rank: Any = ...
    drop_last: Any = ...
    epoch: int = ...
    num_samples: Any = ...
    total_size: Any = ...
    def __init__(
        self,
        dataset: Any,
        batch_size: Any,
        num_replicas: Optional[Any] = ...,
        rank: Optional[Any] = ...,
        shuffle: bool = ...,
        drop_last: bool = ...,
    ) -> None: ...
    def __iter__(self) -> Any: ...
    def __len__(self): ...
    def set_epoch(self, epoch: Any) -> None: ...



from __future__ import annotations

from ... import Tensor, nn

class LeNet(nn.Layer):
    def __init__(self, num_classes: int = ...) -> None: ...
    def forward(self, inputs: Tensor) -> Tensor: ...
    __call__ = forward



from __future__ import annotations

from typing import Any

from paddle.fluid.executor import Executor as Executor

def normalize_program(program: Any, feed_vars: Any, fetch_vars: Any): ...
def is_persistable(var: Any): ...
def serialize_program(feed_vars: Any, fetch_vars: Any, **kwargs: Any): ...
def serialize_persistables(feed_vars: Any, fetch_vars: Any, executor: Any, **kwargs: Any): ...
def save_to_file(path: Any, content: Any) -> None: ...
def save_inference_model(path_prefix: Any, feed_vars: Any, fetch_vars: Any, executor: Any, **kwargs: Any) -> None: ...
def deserialize_program(data: Any): ...
def deserialize_persistables(program: Any, data: Any, executor: Any) -> None: ...
def load_from_file(path: Any): ...
def load_inference_model(path_prefix: Any, executor: Any, **kwargs: Any): ...
